@@ -1,9 +1,6 @@
--- Don't run away from master ship
-mem.norun = true
-mem.carrier = true -- Is a carried fighter
-
 -- Simple create function
 function create ()
+   create_pre()
    create_post()
 
    -- Inherit some properties from the parent (leader)
@@ -12,11 +9,12 @@ function create ()
    if l then
       local lmem = l:memory()
       mem.atk_kill = lmem.atk_kill
+      mem.aggressive = lmem.aggressive
+      mem.enemyclose = lmem.enemyclose
    end
 end
 
 -- Just tries to guard mem.escort
--- luacheck: globals idle (AI Task functions passed by name)
 function idle ()
    ai.pushtask("follow_fleet")
 end
