@@ -1,10 +1,12 @@
+local atklib = require "ai.core.attack"
+local atk = require "ai.core.attack.util"
 local atk_generic = require "ai.core.attack.generic"
 local fmt = require "format"
 local formation = require "formation"
 local lanes = require 'ai.core.misc.lanes'
 local scans = require 'ai.core.misc.scans'
 
-local choose_weapset, clean_task, gen_distress, gen_distress_attacked, handle_messages, lead_fleet, should_cooldown -- Forward-declared functions
+local choose_weapset, clean_task, gen_distress, gen_distress_attacked, handle_messages, lead_fleet, should_cooldown, consider_taunt -- Forward-declared functions
 
 --[[
 -- Variables to adjust AI
@@ -17,8 +19,8 @@ mem.atk_aim       = 1.0 -- Distance that marks aim
 mem.atk_board     = false -- Whether or not to board the target
 mem.atk_kill      = true -- Whether or not to finish off the target
 mem.atk_minammo   = 0.1 -- Percent of ammo necessary to do ranged attacks
+mem.vulnattack    = 1.5 -- Vulnerability threshold
 mem.ranged_ammo   = 0 -- How much ammo is left, we initialize to 0 here just in case
-mem.aggressive    = true --whether to take the more aggressive or more evasive option when given
 mem.recharge      = false --whether to hold off shooting to avoid running dry of energy
 mem.enemyclose    = nil -- Distance at which an enemy is considered close
 mem.armour_run    = -1 -- At which damage to run at
@@ -35,6 +37,7 @@ mem.safe_jump_distance = 300 -- Safe distance from enemies to jump
 mem.land_planet   = true -- Should land on planets?
 mem.land_friendly = false -- Only land on friendly planets?
 mem.distress      = true -- AI distresses
+mem.distress_hit  = 0 -- Amount of faction lost on distress
 mem.distressrate  = 3 -- Number of ticks before calling for help
 mem.distressmsg   = nil -- Message when calling for help
 mem.distressmsgfunc = nil -- Function to call when distressing
@@ -66,6 +69,8 @@ mem.Kd             = 20 -- Second control coefficient (this value is overwritten
 
 mem.target_bias    = vec2.new(0,0) -- Initialize land bias, just in case
 
+mem.elapsed       = 0 -- Time elapsed since pilot was created
+
 -- Required control rate that represents the number of seconds between each
 -- control() call
 control_rate   = 2
@@ -100,6 +105,7 @@ local stateinfo = {
    },
    backoff = {
       running  = true,
+      fighting = true,
       noattack = true,
    },
    runaway = {
@@ -133,27 +139,9 @@ end
    Attack wrappers for calling the correct attack functions.
 --]]
 
-
---[[
--- Wrapper for the think functions.
---]]
-local function attack_think( target, si )
-   -- Ignore other enemies
-   if si.noattack then return end
-
-   -- Update some high level stats
-   mem.ranged_ammo = ai.getweapammo(4)
-
-   local lib = (mem.atk or atk_generic)
-   local func = (lib.think or atk_generic.think)
-   func( target, si )
-end
-
-
 --[[
 -- Wrapper for the attack functions.
 --]]
--- luacheck: globals attack (AI Task functions passed by name)
 function attack( target )
    -- Don't go on the offensive when in the middle of cooling.
    if mem.cooldown then
@@ -176,76 +164,35 @@ end
 --[[
 -- Forced attack function that should focus on the enemy until enemy is killed
 --]]
--- luacheck: globals attack_forced_kill (AI Task functions passed by name)
 function attack_forced_kill( target )
    local lib = (mem.atk or atk_generic)
    lib.atk( target, true )
 end
 
---[[
--- Wrapper for the attacked function. Only called from "attack" tasks (i.e., under "if si.attack").
---]]
-local function attack_attacked( attacker )
-   local lib = (mem.atk or atk_generic)
-   local func = (lib.attacked or atk_generic.attacked)
-   func( attacker )
-end
-
-
--- [[
--- Generic function to choose what attack functions match the ship best.
--- ]]
-local function attack_choose ()
-   local class = ai.pilot():ship():class()
-
-   -- Set initial variables
-   mem.ranged_ammo = ai.getweapammo(4)
-
-   -- Lighter ships
-   if class == "Bomber" then
-      mem.atk = require "ai.core.attack.bomber"
-
-   elseif class == "Interceptor" then
-      mem.atk = require "ai.core.attack.drone"
-
-   elseif class == "Fighter" then
-      mem.atk = require "ai.core.attack.fighter"
-
-   -- Medium ships
-   elseif class == "Corvette" then
-      mem.atk = require "ai.core.attack.corvette"
-
-   -- Capital ships
-   elseif class == "Destroyer" or class == "Cruiser" or class == "Battleship" or class == "Carrier" then
-      mem.atk = require "ai.core.attack.capital"
-
-    -- Generic AI
-   else
-      mem.atk = atk_generic
-   end
-end
-
 function lead_fleet( p )
-   if #p:followers() ~= 0 then
-      if mem.formation == nil then
-         formation.clear(p)
-         return
-      end
+   if #p:followers() == 0 then
+      return
+   end
+   if mem.formation == nil then
+      formation.clear(p)
+      return
+   end
 
-      local form = formation[mem.formation]
-      if form == nil then
-         warn(fmt.f(_("Pilot '{plt}': formation '{formation}' not found!"), {plt=p, formation=mem.formation}))
-      else
-         form(p)
-      end
+   local form = formation[mem.formation]
+   if form == nil then
+      warn(fmt.f(_("Pilot '{plt}': formation '{formation}' not found!"), {plt=p, formation=mem.formation}))
+   else
+      form(p)
    end
 end
 
 -- Run instead of "control" when under manual control; use should be limited
-function control_manual ()
+function control_manual( dt )
+   mem.elapsed = mem.elapsed + dt
    local p = ai.pilot()
    local task = ai.taskname()
    local si = _stateinfo( task )
+   ai.combat( si.fighting )
 
    lead_fleet( p )
    handle_messages( si, false )
@@ -255,49 +202,32 @@ function handle_messages( si, dopush )
    local taskchange = false
    local p = ai.pilot()
    local l = p:leader()
-   for _, msg in ipairs(ai.messages()) do
-      local sender, msgtype, data = table.unpack(msg)
+   for i, msg in ipairs(ai.messages()) do
+      local sender, msgtype, data = msg[1], msg[2], msg[3]
 
-      -- Skip message from nonexistent sender
-      if sender:exists() then
+      -- This is the case that the message is being sent from the environment, such as asteroids
+      if sender==nil then
+         -- Asteroid was blown up with mining tools
+         if msgtype=="asteroid" and data and data:exists() then
+            local ap = data:pos()
+            if dopush and should_investigate( ap, si ) then
+               ap = ap + vec2.newP( 500*rnd.rnd(), rnd.angle () )
+               ai.pushtask("inspect_moveto", ap )
+               taskchange = true
+            end
 
-         -- Below we only handle if they came from allies
-         -- (So far, only allies would send in the first place, but this check future-proofs things.
-         -- One day it might be interesting to have non-allied snitches whose tips get checked out...)
-         if p:faction():areAllies( sender:faction() ) then
-            if msgtype == "scanned" then
-               if mem.doscans and data ~= nil and data:exists() then
-                  mem.scanned = mem.scanned or {} -- Create table if doesn't exist
-                  table.insert( mem.scanned, data )
-                  -- Stop scanning if they got information about the scan
-                  if ai.taskname() == "scan" and ai.taskdata() == data then
-                     ai.poptask()
-                     taskchange = true
-                  end
-               end
+         -- Some signal was detected
+         elseif msgtype=="signal" and data then
+            if dopush and should_investigate( data, si ) then
+               ai.pushtask("inspect_moveto", data )
+               taskchange = true
             end
          end
+      else
 
-         -- Messages coming from followers
-         if sender:leader() == p then
-            if msgtype == "f_attacked" then
-               if not si.fighting and should_attack( data, si ) then
-                  -- Also signal to other followers
-                  for k,v in ipairs(p:followers()) do
-                     p:msg( v, "l_attacked", data )
-                  end
-                  if dopush then
-                     ai.pushtask("attack", data)
-                     taskchange = true
-                  end
-               end
-            end
-
-         -- Below we only handle if they came from the glorious leader
-         elseif sender == l then
-            if msgtype == "form-pos" then
-               mem.form_pos = data
-            elseif msgtype == "hyperspace" then
+         -- Special case leader is gone but we want to follow, so we ignore if they're non-existent.
+         if l==nil or sender==l then
+            if msgtype == "hyperspace" then
                if dopush then
                   ai.pushtask("hyperspace", data)
                   taskchange = true
@@ -307,42 +237,85 @@ function handle_messages( si, dopush )
                   ai.pushtask("land", data)
                   taskchange = true
                end
-            elseif msgtype == "l_attacked" then
-               if not si.fighting and should_attack( data, si ) then
-                  if dopush then
-                     ai.pushtask("attack", data)
-                     taskchange = true
-                  end
-               end
+            end
+         end
 
-            -- Escort commands
-            elseif dopush then
-               -- Attack target
-               if msgtype == "e_attack" then
-                  if data ~= nil and data:exists() then
-                     if data:leader() ~= l then -- Don't kill from same team
-                        clean_task()
-                        --if (si.attack and si.forced and ai.taskdata()==data) or data:flags("disabled") then
-                        if data:flags("disabled") then
-                           ai.pushtask("attack_forced_kill", data)
-                        else
-                           ai.pushtask("attack_forced", data)
-                        end
+         -- Skip message from nonexistent sender
+         if sender:exists() then
+
+            -- Below we only handle if they came from allies
+            -- (So far, only allies would send in the first place, but this check future-proofs things.
+            -- One day it might be interesting to have non-allied snitches whose tips get checked out...)
+            if p:faction():areAllies( sender:faction() ) then
+               if msgtype == "scanned" then
+                  if mem.doscans and data ~= nil and data:exists() then
+                     mem.scanned = mem.scanned or {} -- Create table if doesn't exist
+                     table.insert( mem.scanned, data )
+                     -- Stop scanning if they got information about the scan
+                     if ai.taskname() == "scan" and ai.taskdata() == data then
+                        ai.poptask()
                         taskchange = true
                      end
                   end
-               -- Hold position
-               elseif msgtype == "e_hold" then
-                  ai.pushtask("hold")
-                  taskchange = true
-               -- Return to carrier
-               elseif msgtype == "e_return" then
-                  ai.pushtask( "flyback", p:flags("carried") )
-                  taskchange = true
-               -- Clear orders
-               elseif msgtype == "e_clear" then
-                  p:taskClear()
-                  taskchange = true
+               end
+            end
+
+            -- Messages coming from followers
+            if sender:leader() == p then
+               if msgtype == "f_attacked" then
+                  if not si.fighting and should_attack( data, si, true ) then
+                     -- Also signal to other followers
+                     for k,v in ipairs(p:followers()) do
+                        p:msg( v, "l_attacked", data )
+                     end
+                     if dopush then
+                        ai.pushtask("attack", data)
+                        taskchange = true
+                     end
+                  end
+               end
+
+            -- Below we only handle if they came from the glorious leader
+            elseif sender == l then
+               if msgtype == "form-pos" then
+                  mem.form_pos = data
+               elseif msgtype == "l_attacked" then
+                  if not si.fighting and should_attack( data, si, true ) then
+                     if dopush then
+                        ai.pushtask("attack", data)
+                        taskchange = true
+                     end
+                  end
+
+               -- Escort commands
+               elseif dopush then
+                  -- Attack target
+                  if msgtype == "e_attack" then
+                     if data ~= nil and data:exists() then
+                        if data:leader() ~= l then -- Don't kill from same team
+                           clean_task()
+                           --if (si.attack and si.forced and ai.taskdata()==data) or data:flags("disabled") then
+                           if data:flags("disabled") then
+                              ai.pushtask("attack_forced_kill", data)
+                           else
+                              ai.pushtask("attack_forced", data)
+                           end
+                           taskchange = true
+                        end
+                     end
+                  -- Hold position
+                  elseif msgtype == "e_hold" then
+                     ai.pushtask("hold")
+                     taskchange = true
+                  -- Return to carrier
+                  elseif msgtype == "e_return" then
+                     ai.pushtask( "flyback", mem.carried )
+                     taskchange = true
+                  -- Clear orders
+                  elseif msgtype == "e_clear" then
+                     p:taskClear()
+                     taskchange = true
+                  end
                end
             end
          end
@@ -362,18 +335,24 @@ local function sameFleet( pa, pb )
    return la == lb
 end
 
-
-function should_attack( enemy, si )
+--[[
+-- Whether or not the pilot should try to attack an enemy.
+--]]
+function should_attack( enemy, si, aggressor )
    if not enemy or not enemy:exists() then
       return false
    end
 
-   if not mem.aggressive then
+   if not aggressor and not mem.aggressive then
       return false
    end
 
    si = si or _stateinfo( ai.taskname() )
 
+   if si.noattack then
+      return false
+   end
+
    -- Don't reattack the current enemy
    if si.attack and enemy==ai.taskdata() then
       return false
@@ -382,7 +361,7 @@ function should_attack( enemy, si )
    -- Try to follow the leader behaviour
    local p = ai.pilot()
    local l = p:leader()
-   if l and l:exists() then
+   if l then
       local ltask, ldata = l:task()
       local lsi = _stateinfo( ltask )
       if lsi.fighting then
@@ -418,8 +397,49 @@ function should_attack( enemy, si )
    return false
 end
 
+--[[
+-- Whether or not the pilot should investigate a certain location.
+--]]
+function should_investigate( pos, si )
+   if si.fighting or si.forced or si.noattack then
+      return false
+   end
+
+   -- Only care about scanning
+   if not mem.doscans or rnd.rnd() < 0.8 then
+      return false
+   end
+
+   -- Conmfort
+   local ec = mem.enemyclose or math.huge
+   local ec2 = ec*ec
+
+   -- Should be nearby
+   if ai.dist2(pos) > ec2 then
+      return false
+   end
+
+   -- Check to see if we want to go back to the lanes
+   if mem.natural and ec < math.huge then
+      local d, _pos = lanes.getDistance2P( ai.pilot(), pos )
+      if math.huge > d and d > ec2 then
+         return false
+      end
+   end
+
+   return true
+end
+
+--[[
+-- Table of think functions for the different tasks (uses task name as an index).
+-- These are used after the general thought process, including things like
+-- handling messages and running away.
+--
+-- They should return true if the pilot is not interested in attacking while
+-- doing the task, or false otherwise.
+--]]
 control_funcs = {}
-function control_funcs.generic_attack( si )
+function control_funcs.generic_attack( si, noretarget )
    si = si or _stateinfo( ai.taskname() )
    local target = ai.taskdata()
    -- Needs to have a target
@@ -446,41 +466,45 @@ function control_funcs.generic_attack( si )
       -- Cool down, if necessary.
       should_cooldown()
 
-      attack_think( target, si )
+      atklib.think( target, si, noretarget )
    end
 
    -- Handle distress
-   gen_distress()
+   gen_distress( target )
    return false
 end
 
 -- Required "control" function
-function control ()
+function control( dt )
+   mem.elapsed = mem.elapsed + dt
    local p = ai.pilot()
-   local enemy = ai.getenemy()
+   local enemy = atk.preferred_enemy()
 
    -- Task information stuff
    local task = ai.taskname()
    local si = _stateinfo( task )
+   ai.combat( si.fighting )
 
    lead_fleet( p )
    local taskchange = handle_messages( si, true )
 
    -- Select new leader
    local l = p:leader()
-   if l ~= nil and not l:exists() then
-      local candidate = ai.getBoss()
-      if candidate ~= nil and candidate:exists() then
-         p:setLeader( candidate )
-         l = candidate
-      else -- Indicate this pilot has no leader
-         p:setLeader( nil )
-         l = nil
+   if not mem.carried then -- carried ships don't change
+      if l == nil and mem.autoleader then
+         local candidate = ai.getBoss()
+         if candidate ~= nil and candidate:exists() then
+            p:setLeader( candidate )
+            l = candidate
+         else -- Indicate this pilot has no leader
+            p:setLeader( nil )
+            l = nil
+         end
       end
    end
 
    -- Try to stealth if leader is stealthed
-   if l ~= nil then
+   if l then
       if l:flags("stealth") then
          ai.stealth(true)
       elseif p:flags("stealth") then
@@ -577,9 +601,9 @@ function control ()
    -- Get new task
    if task == nil then
       -- See what decision to take
-      if should_attack( enemy, si ) then
+      if should_attack( enemy, si, false ) then
          ai.hostile(enemy) -- Should be done before taunting
-         taunt(enemy, true)
+         consider_taunt(enemy, true)
          ai.pushtask("attack", enemy)
       elseif l then -- Leader should be set already
          ai.pushtask("follow_fleet")
@@ -602,15 +626,10 @@ function control ()
 
    -- Enemy sighted, handled doing specific tasks
    if enemy ~= nil and mem.aggressive then
-      -- Don't start new attacks while refueling.
-      if si.noattack then
-         return
-      end
-
       -- See if really want to attack
-      if should_attack( enemy, si ) then
+      if should_attack( enemy, si, false ) then
          ai.hostile(enemy) -- Should be done before taunting
-         taunt(enemy, true)
+         consider_taunt(enemy, true)
          clean_task()
          ai.pushtask("attack", enemy)
       end
@@ -665,7 +684,7 @@ function control_funcs.runaway ()
       ai.hyperspace()
    else
       -- If far enough away, stop the task
-      local enemy = ai.getenemy() -- nearest enemy
+      local enemy = atk.preferred_enemy() -- nearest enemy
       if not enemy or (enemy and ai.dist(enemy) > mem.safe_distance) then
          ai.poptask()
          return true
@@ -673,7 +692,7 @@ function control_funcs.runaway ()
    end
 
    -- Handle distress
-   gen_distress()
+   gen_distress( target )
    return true
 end
 function control_funcs.board ()
@@ -687,7 +706,7 @@ function control_funcs.board ()
       return true
    end
    -- We want to think in case another attacker gets close
-   attack_think( target, si )
+   atklib.think( target, si )
    return true
 end
 function control_funcs.attack ()
@@ -695,7 +714,7 @@ function control_funcs.attack ()
 end
 function control_funcs.attack_forced ()
    -- Independent of control_funcs.attack
-   control_funcs.generic_attack()
+   control_funcs.generic_attack( nil, true )
    return true
 end
 function control_funcs.flyback () return true end
@@ -733,7 +752,7 @@ function attacked_manual( attacker )
          p:msg( v, "l_attacked", attacker )
       end
       local l = p:leader()
-      if l and l:exists() then
+      if l then
          p:msg( l, "f_attacked", attacker )
       end
    end
@@ -756,6 +775,7 @@ function attacked( attacker )
    local p = ai.pilot()
    if not mem.attacked then
       mem.attacked = true
+      mem.found_illegal = false -- We clear here so the player can't attack and still bribe
       if ai.hasfighterbays() then
          for k,v in ipairs(p:followers()) do
             p:msg( v, "e_clear" )
@@ -771,7 +791,7 @@ function attacked( attacker )
 
    -- Cooldown should be left running if not taking heavy damage.
    if mem.cooldown then
-      local _, pshield = p:health()
+      local _a, pshield = p:health()
       if pshield < 90 then
          mem.cooldown = false
          p:setCooldown( false )
@@ -786,7 +806,7 @@ function attacked( attacker )
          p:msg( v, "l_attacked", attacker )
       end
       local l = p:leader()
-      if l and l:exists() then
+      if l then
          p:msg( l, "f_attacked", attacker )
       end
    end
@@ -801,7 +821,7 @@ function attacked( attacker )
       if mem.defensive then
          -- Some taunting
          ai.hostile(attacker) -- Should be done before taunting
-         taunt( attacker, false )
+         consider_taunt( attacker, false )
 
          -- Now pilot fights back
          clean_task( task )
@@ -816,7 +836,7 @@ function attacked( attacker )
 
    -- Let attacker profile handle it.
    elseif si.attack then
-      attack_attacked( attacker )
+      atklib.attacked( attacker )
 
    elseif task == "runaway" then
       if ai.taskdata() ~= attacker and not mem.norun then
@@ -828,26 +848,25 @@ end
 
 -- Default create function just runs create_post
 function create ()
+   create_pre()
    create_post()
 end
 
--- Finishes create stuff like choose attack and prepare plans
-function create_post ()
+-- Sets up some per-pilot defaults that can be overriden afterwards
+function create_pre ()
    local p        = ai.pilot()
    mem.tookoff    = p:flags("takingoff")
    mem.jumpedin   = p:flags("jumpingin")
-   mem.scanned    = {} -- must create for each pilot
-   attack_choose()
+   mem.carried    = p:flags("carried")
+   mem.mothership = p:mothership()
 
-   -- Give a small delay... except for escorts?
-   if mem.jumpedin and not mem.carrier then
-      ai.settimer( 0, rnd.uniform(5.0, 6.0) )
-      ai.pushtask("jumpin_wait")
-   end
+   -- Amount of faction lost when the pilot distresses at the player
+   -- Should be roughly 1 for a 20 point llama and 4.38 for a 150 point hawking
+   mem.distress_hit = math.max( 0, math.pow( p:ship():points(), 0.37 )-2)
 
    -- Tune PD parameter (with a nice heuristic formula)
    local ps = p:stats()
-   mem.Kd = math.max( 5., 10.84 * (180./ps.turn + ps.speed/ps.thrust) - 10.82 );
+   mem.Kd = math.max( 5., 10.84 * (180./ps.turn + ps.speed/ps.thrust) - 10.82 )
 
    -- Just give some random fuel
    if p ~= player.pilot() then
@@ -859,6 +878,39 @@ function create_post ()
          p:setFuel( f )
       end
    end
+
+   mem.elapsed = 0 -- Restart elapsed timer
+
+   -- Choose attack algorithm
+   atklib.choose()
+end
+
+-- Finishes create stuff like choose attack and prepare plans
+function create_post ()
+   mem.scanned    = {} -- must create for each pilot
+
+   -- Give a small delay... except for escorts?
+   if mem.jumpedin and not mem.carried then
+      ai.settimer( 0, rnd.uniform(5.0, 6.0) )
+      ai.pushtask("jumpin_wait")
+   end
+
+   -- Fighters give much smaller faction hits
+   if mem.carried then
+      mem.distress_hit = mem.distress_hit * 0.1
+   end
+end
+
+-- Set transport ship parameters
+function transportParam ( price )
+   mem.aggressive  = false
+   mem.whiteknight = false
+   mem.loiter      = 0
+   mem.land_planet = true
+   mem.defensive   = false
+   mem.enemyclose  = 500
+   mem.careful     = true
+   ai.setcredits( rnd.rnd(price/100, price/25) )
 end
 
 -- taunts
@@ -866,6 +918,16 @@ function taunt( _target, _offensive )
    -- Empty stub
 end
 
+-- Lower taunt frequency, at most once per X seconds per target
+mem._taunted = {}
+function consider_taunt( target, offensive )
+   local id = target:id()
+   local last_taunted = mem._taunted[id] or -100
+   if mem.elapsed - last_taunted > 15 then
+      taunt( target, offensive )
+      mem._taunted[id] = mem.elapsed
+   end
+end
 
 -- Handle distress signals
 function distress( pilot, attacker )
@@ -920,9 +982,8 @@ function distress( pilot, attacker )
    local si   = _stateinfo( task )
    -- Already fighting
    if si.attack then
-      if si.noattack then return end
       -- Ignore if not interested in attacking
-      if not should_attack( badguy, si ) then return end
+      if not should_attack( badguy, si, false ) then return end
 
       local target = ai.taskdata()
 
@@ -936,7 +997,7 @@ function distress( pilot, attacker )
    elseif task ~= "runaway" and task ~= "refuel" then
       if not si.noattack and mem.aggressive then
          -- Ignore if not interested in attacking
-         if not should_attack( badguy, si ) then return end
+         if not should_attack( badguy, si, false ) then return end
          if p:inrange( badguy ) then -- TODO: something to help in the other case
             clean_task( task )
             ai.pushtask( "attack", badguy )
@@ -951,7 +1012,7 @@ end
 
 
 -- Handles generating distress messages
-function gen_distress( _target )
+function gen_distress( target )
    if not mem.distress then return end
 
    -- Must have a valid distress rate
@@ -975,7 +1036,7 @@ function gen_distress( _target )
    -- See if it's time to trigger distress
    if mem.distressed > mem.distressrate then
       if mem.distressmsgfunc then
-         mem.distressmsgfunc()
+         mem.distressmsgfunc( target )
       else
          ai.distress( mem.distressmsg )
       end
@@ -983,14 +1044,14 @@ function gen_distress( _target )
    end
 end
 
-function gen_distress_attacked( _attacker )
+function gen_distress_attacked( attacker )
    if not mem.distress then return end
 
    -- Already attacked so ignore new hits (should reset)
    if mem.attacked then return end
 
    if mem.distressmsgfunc then
-      mem.distressmsgfunc()
+      mem.distressmsgfunc( attacker )
    else
       ai.distress( mem.distressmsg )
    end
