@@ -1,7 +1,7 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <event name="FLF Catastrophe">
- <trigger>enter</trigger>
+ <location>enter</location>
  <chance>70</chance>
  <cond>system.cur() == system.get("Sigur") and faction.get("FLF"):playerStanding() &gt;= 98 and player.misnDone("The FLF Split")</cond>
  <notes>
@@ -19,9 +19,9 @@ local fleet = require "fleet"
 local flf = require "missions.flf.flf_common"
 local fmt = require "format"
 local lmisn = require "lmisn"
+local cinema = require "cinema"
 
 local dv_ships, emp_ships, flf_ships, flf_base -- State of battle phase (jumping out to save not allowed).
--- luacheck: globals enter_bar jumpin land pilot_attacked_sindbad pilot_death_emp pilot_death_sindbad takeoff takeoff_abort timer_end timer_plcontrol timer_thurion (Hook functions passed by name)
 
 -- Event constants
 local emp_srcsys = system.get( "Arcanis" )
@@ -52,18 +52,14 @@ function enter_bar ()
    if not lmisn.anyMissionActive( flf_missions ) then
       hook.rm( mem.bar_hook )
       hook.rm( mem.abort_hook )
-      music.stop()
-      music.load( "tension" )
-      music.play()
-      var.push( "music_off", true )
+      music.play( "tension.ogg" )
       tk.msg( _("Catastrophe Looms"), _([[As you enter the bar on Sindbad, you immediately know that something is wrong. Everyone is frantic and you sense dread around your comrades. You are about to ask around when Benito approaches.]]) )
       tk.msg( _("Catastrophe Looms"), fmt.f( _([["{player}, it's horrible," she says with a look of dread in her eyes. "They found us. The damn Empire found us! I'm going to be frank, I don't even know if we can survive this." You stammer for a moment. No, it can't be true! It has to be some mistake! How can the FLF be defeated like this? Now the commotion makes perfect sense.
     "It's those damn traitors!" Benito continues. "One of them went off and told the Empire where our base is, and they even told them where our hidden jumps are! This is terrible!"]]), {player=player.name()} ) )
       tk.msg( _("Catastrophe Looms"), fmt.f( _([["Listen, we don't have much longer. A combined Empire and Dvaered fleet is just about to enter from {sys}. They have Peacemakers, Hawkings, Goddards, Pacifiers, you name it. They're ready to wipe us off the map. {player}, I don't know how to say this, but..." Benito digs in her pockets a bit before pulling out a small data chip. "Here, take this," she says as she presses it into your hand. "That's plan B. I hope it doesn't come to that, but... keep it safe, just in case."
-    Benito clears her throat. "But I'm sure you can guess what your mission is. You need to join with the others in the fight against the incoming Empire ships. You have to destroy all of the ships. I will be here helping to man the station; our defenses are weak, but better than nothing."]]), {sys=emp_srcsys, player=player.name()} ) )
+    Benito clears her throat. "But I'm sure you can guess what your mission is. You need to join with the others in the fight against the incoming Empire ships. You have to destroy all of the ships. I will be here helping to man the station; our defences are weak, but better than nothing."]]), {sys=emp_srcsys, player=player.name()} ) )
       tk.msg( _("Catastrophe Looms"), _([[Silence seems to engulf the room. You see the mouths of your comrades frantically talking, but you cannot hear them. Benito puts her hand on your shoulder and looks at you in the eye. "Don't die, soldier," she says, only this time, it's not in the usual playful tone you tend to expect of her. She then hurriedly exits toward the station's weapon controls room.]]) )
       tk.msg( _("Catastrophe Looms"), _([[There's no time to lose. You go to the hangar bay and immediately take off.]]) )
-      var.pop( "music_off" )
 
       mem.takeoff_hook = hook.enter( "takeoff" )
       player.takeoff()
@@ -82,11 +78,9 @@ function takeoff ()
    pilot.toggleSpawn( false )
    pilot.clear()
 
-   local ss, _s = planet.getS( "Sindbad" )
+   local ss = spob.get( "Sindbad" )
 
-   flf_base = pilot.add( "Sindbad", "FLF", ss:pos(), nil, {ai="flf_norun"} )
-   flf_base:outfitRm( "all" )
-   flf_base:outfitRm( "cores" )
+   flf_base = pilot.add( "Sindbad", "FLF", ss:pos(), nil, {ai="flf_norun", naked=true} )
    flf_base:outfitAdd( "Dummy Systems" )
    flf_base:outfitAdd( "Dummy Plating" )
    flf_base:outfitAdd( "Dummy Engine" )
@@ -177,7 +171,7 @@ end
 
 
 function pilot_attacked_sindbad( _pilot, attacker, _arg )
-   if (attacker == player.pilot() or attacker:leader() == player.pilot())
+   if attacker and attacker:withPlayer()
          and faction.get("FLF"):playerStanding() > -100 then
       -- Punish the player with a faction hit every time they attack
       faction.get("FLF"):modPlayer(-10)
@@ -214,7 +208,7 @@ function pilot_death_sindbad( pilot, attacker, _arg )
       end
    end
 
-   if attacker == player.pilot() or attacker:leader() == player.pilot()
+   if (attacker and attacker:withPlayer())
          or faction.get("FLF"):playerStanding() < 0 then
       -- Player decided to help destroy Sindbad for some reason. Set FLF
       -- reputation to "enemy", add a log entry, and finish the event
@@ -224,14 +218,11 @@ function pilot_death_sindbad( pilot, attacker, _arg )
       evt.finish( true )
    end
 
-   music.stop()
-   music.load( "machina" )
-   music.play()
+   music.play( "machina.ogg" )
    var.push( "music_wait", true )
 
-   player.pilot():setInvincible()
-   player.cinematics()
-   camera.set( flf_base )
+   cinema.on()
+   camera.set( flf_base, true )
 
    tk.msg( _("Escape and Live On"), _([[As the last shot penetrates the hull of Sindbad, a sense of dread comes over you. The FLF, Benito, your comrades... no...
     Just as you think this, the now exploding station hails you. You immediately accept, and you see Benito on your screen once again. You hear sirens and explosions in the background, but you pay them no mind.]]) )
@@ -248,8 +239,8 @@ end
 
 
 function timer_plcontrol ()
-   camera.set( player.pilot() )
-   player.cinematics( false )
+   cinema.off()
+   camera.set( player.pilot(), true )
    hook.timer( 2.0, "timer_end" )
 end
 
@@ -262,8 +253,7 @@ end
 function jumpin ()
    if not mem.found_thurion and system.cur() == system.get("Oriantis") then
       music.stop()
-      music.load( "intro" )
-      music.play()
+      music.play( "intro.ogg" )
       var.push( "music_wait", true )
       hook.timer( 5.0, "timer_thurion" )
    elseif mem.found_thurion and system.cur() == system.get("Metsys") then
@@ -284,7 +274,7 @@ end
 
 
 function land ()
-   if planet.cur():faction() == faction.get("Thurion") then
+   if spob.cur():faction() == faction.get("Thurion") then
       tk.msg( _("Welcome To the Nebula"), _([[As you land on the mysterious station, armed guards immediately surround your ship and order you out into the hangar. You comply, and they take you to a room that appears to be an interrogation room, where you wait for a few nerve-wracking hectoseconds. Finally, a holoscreen flickers on, showing the figure you had seen earlier. She looks in your direction.
     "Well met," she says. "I see you have made the right choice and survived the nebula. Very good."]]) )
       tk.msg( _("Welcome To the Nebula"), _([["I'm sure you're wondering who we are. We are the Thurion, a civilization left over from one of the Empire's former secret projects. Have you met the Za'lek? The Collective? Those too were the Empire's "great projects", as were the now dead Proteron. But we were kept a lot more in the dark.
@@ -292,7 +282,7 @@ function land ()
       tk.msg( _("Welcome To the Nebula"), _([["Now, about half of us are uploaded, myself included. This face you see and this voice you hear are but projections, a reflection of myself that I have freely chosen. Being uploaded is wonderful, I must say; there is no suffering, we are immortal, and we can have whatever human experiences we desire and much more. And when we decide we have lived to our fullest, we can delete ourselves and disappear into the emptiness just like any other person does when they die. It's not uncommon for people to choose to self-terminate after they have been uploaded for about 200 cycles or so. I, however, have stuck around from the very beginning. I very much enjoy seeing the biological Thurion grow, learn, and join us in uploaded consciousness when their human bodies grow old and weary.
     "Sadly, I don't think you can be uploaded. The uploading process tends to fail with people who have even the slightest brain damage, and you outsiders usually drink far too many brain-damaging substances. That said, the time to check if you are eligible for uploading is many cycles away anyhow, so we'll see when we get there, should you have an interest in being uploaded."]]) )
       tk.msg( _("Welcome To the Nebula"), fmt.f( _([[Fascinated, you finally speak up, prompting a smile from the uploaded Thurion and a fairly long, friendly discussion about her experiences as an uploaded Thurion and your experience as a pilot on the outside. You find out that her name is Alicia. Somewhere in the conversation, a pair of human Thurion guards enters the room. They ask Alicia how it went, and she says that you've been properly introduced to Thurion culture and can be trusted to roam free. The two guards then smile and shake your hand. "Welcome to the nebula, {player}," one of them says. "You now have permission to roam Thurion space freely and conduct your business. Of course, I trust you won't reveal our secret location to anyone. That would be just as bad for you as it would be for us."
-    You affirm that you will keep the Thurion's secret safe. "Yes, welcome," Alicia says. "And do check out our bars and mission computers from time to time. We very well might have some missions for you in the future. In the meantime, buy yourself one of our nebula-resistant ships, and make yourself comfortable. You are our honored guest and, I hope, the first of many outsiders to learn the wonders of our way of life."
+    You affirm that you will keep the Thurion's secret safe. "Yes, welcome," Alicia says. "And do check out our bars and mission computers from time to time. We very well might have some missions for you in the future. In the meantime, buy yourself some nebula-resistant coating, and make yourself comfortable. You are our honored guest and, I hope, the first of many outsiders to learn the wonders of our way of life."
     The guards then promptly but politely escort you back to your ship, which has been refueled while you were gone. This should be an interesting experience....]]), {player=player.name()} ) )
       faction.get("Thurion"):setKnown( true )
       flf.addLog( _([[Having braved the nebula, you were introduced to the Thurion by Alicia, one of many uploaded Thurion. The Thurion are the remnants of a secret project initiated by the Empire, Project Thurion. The Za'lek, the Collective, and the now-dead Proteron were also "great projects" of the Empire, but Project Thurion was seen as an embarrassment, prompting the Empire to attempt to kill the Thurion so word of their existence wouldn't get out. However, the Thurion learned a way to upload the human mind to a computer, allowing them to escape and rebuild.
