@@ -1,9 +1,9 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <event name="Minerva Station Gambling">
- <trigger>land</trigger>
+ <location>land</location>
  <chance>100</chance>
- <cond>planet.cur()==planet.get("Minerva Station")</cond>
+ <cond>spob.cur()==spob.get("Minerva Station")</cond>
  <notes>
   <campaign>Minerva</campaign>
   <provides name="Minerva Station" />
@@ -24,8 +24,6 @@ local window = require 'love.window'
 --local love_shaders = require 'love_shaders'
 
 local npc_patrons -- Non-persistent state
--- luacheck: globals bargreeter leave molecaught start_alter1 start_alter2 start_spapropaganda (Hook functions passed by name)
--- luacheck: globals approach_blackjack approach_chuckaluck approach_maikki approach_patron approach_scavengers approach_terminal (NPC functions passed by name)
 
 -- NPC Stuff
 local gambling_priority = 3
@@ -70,7 +68,7 @@ local patron_messages = {
    _([["This place is great! I still have no idea how to play blackjack, but I just keep on playing again and again against that Cyborg Chicken."]]),
    function () return fmt.f(
       _([["I came all the way from {pnt} to be here! We don't have anything like this back at home."]]),
-      {pnt=planet.get( {faction.get("Dvaered"), faction.get("Za'lek"), faction.get("Empire"), faction.get("Soromid")} )}
+      {pnt=spob.get( {faction.get("Dvaered"), faction.get("Za'lek"), faction.get("Empire"), faction.get("Soromid")} )}
    ) end,
    _([["Critics of Minerva Station say that being able to acquire nice outfits here without needing licenses increases piracy. I think they are all lame!"]]),
    _([["I really want to go to the VIP hot springs they have, but I don't have the tokens. How does that even work in a space station?"]]),
@@ -125,7 +123,7 @@ function create()
    end
 
    -- If they player never had tokens, it is probably their first time
-   if not var.peek( "minerva_tokens" ) then
+   if not var.peek( "minerva_tokens_gained" ) then
       mem.greeterhook = hook.land( "bargreeter", "bar" )
    end
    -- End event on takeoff.
@@ -351,7 +349,7 @@ WHAT DO YOU WISH TO DO TODAY?"]], minerva.tokens_get()),
             player.outfitAdd( ti[1] )
             player.msg( _("Gambling Bounty"), fmt.reward(ti[1]))
          elseif ti[2][2]=="ship" then
-            player.addShip( ti[1] )
+            player.shipAdd( ti[1] )
          else
             error(_("unknown tradein type"))
          end
