@@ -1,13 +1,12 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <event name="Naev Needs You!">
-  <trigger>land</trigger>
-  <chance>8</chance>
-  <flags>
-   <unique />
-  </flags>
- </event>
- --]]
+ <location>land</location>
+ <chance>8</chance>
+ <cond>player.credits() &gt; 237451</cond>
+ <unique />
+</event>
+--]]
 --[[
 
 EVENT TITLE: Naev Needs You!
@@ -19,7 +18,6 @@ DESCRIPTION:
 
 ]]--
 
--- luacheck: globals enter_system (Hook functions passed by name)
 
 -- Stage one: something goes wrong in fabric of reality.
 local text = {}
@@ -46,43 +44,28 @@ text[3] = _([["Oh sorry about that. We're working hard on improving life, the un
 
 
 function create()
-      -- Event should only occur if player has played a bit.
-      if player.credits() < 237451 then
-         evt.finish( false)
-      end
-
       -- Create an eerie atmosphere by cutting off the background music and substituting something spooky
       --disabled until difficulties with the music API are sorted out
-      local background_music
-      if music.isPlaying() then
-         background_music = music.current()
-         music.stop()
-      end
-      music.load( "sirius1")
-      music.play()
+      music.play( "sirius1.ogg" )
 
       -- The big programmer in the sky looks in to ask the player a question
-      if tk.yesno( _("Naev received SIGSEGV (address not mapped to object)!"), text[1]) then
-         tk.msg( _("The voice of the creator"), text[2]) -- if the answer is 'yes'
+      if tk.yesno( _("Naev received SIGSEGV (address not mapped to object)!"), text[1] ) then
+         tk.msg( _("The voice of the creator"), text[2] ) -- if the answer is 'yes'
 
      -- Mission ends with a little comment after blasting off.
-         -- hook.takeoff( "enter_system")
+         -- hook.takeoff( "enter_system" )
 
       else
-         tk.msg( _("The voice of the creator"), text[3]) -- if the answer is 'no', not much different from 'yes'
+         tk.msg( _("The voice of the creator"), text[3] ) -- if the answer is 'no', not much different from 'yes'
 
      -- Mission ends with a little comment after blasting off.
-         -- hook.takeoff( "enter_system")
+         -- hook.takeoff( "enter_system" )
       end
 
       -- everything returns to normal
-      music.stop()
-      if background_music ~= nil then
-         music.load( background_music )
-         music.play()
-      end
+      music.choose( "land" )
 
-      evt.finish( true)
+      evt.finish( true )
 end
 
 --[[
