@@ -1,7 +1,7 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <event name="Kidnapped">
-  <trigger>enter</trigger>
+  <location>enter</location>
   <chance>15</chance>
   <cond>player.misnDone("Kidnapped") == false and player.misnActive("Kidnapped") == false and system.cur() == system.get("Arcturus") and player.numOutfit("Mercenary License") &gt; 0</cond>
   <notes>
@@ -15,11 +15,10 @@
 --]]
 
 local panma, yohail -- Non-persistent state
--- luacheck: globals finish hail hailme (Hook functions passed by name)
 
 --Create Mom and Dad in their spaceship, and have them come from the planet Brooks in Arcturus system, following the player.
 function create ()
-    local pnt = planet.get("Brooks")
+    local pnt = spob.get("Brooks")
     panma = pilot.add( "Llama", "Independent", pnt )
     panma:control()
     panma:follow(player.pilot())
