@@ -1,19 +1,15 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Prince">
- <flags>
-  <unique />
- </flags>
- <avail>
-  <priority>4</priority>
-  <done>Baron</done>
-  <chance>2</chance>
-  <location>Bar</location>
-  <faction>Empire</faction>
-  <faction>Dvaered</faction>
-  <faction>Goddard</faction>
-  <faction>Sirius</faction>
- </avail>
+ <unique />
+ <priority>4</priority>
+ <done>Baron</done>
+ <chance>2</chance>
+ <location>Bar</location>
+ <faction>Empire</faction>
+ <faction>Dvaered</faction>
+ <faction>Goddard</faction>
+ <faction>Sirius</faction>
  <notes>
   <campaign>Baron Sauterfeldt</campaign>
  </notes>
@@ -30,16 +26,14 @@ local baron = require "common.baron"
 
 -- Mission constants
 local baronsys = system.get("Ingot")
-local artefactplanetA = planet.get("Varaati")
-local artefactplanetB = planet.get("Sinclair")
-local artefactplanetC = planet.get("Hurada")
-local flintplanet, flintsys = planet.getS("Tau Station")
+local artefactplanetA = spob.get("Varaati")
+local artefactplanetB = spob.get("Sinclair")
+local artefactplanetC = spob.get("Hurada")
+local flintplanet, flintsys = spob.getS("Tau Station")
 local reward = baron.rewards.prince
 
 local isIn, mangle -- Forward-declared functions
 local pinnacle -- Non-persistent state
--- luacheck: globals board enter hail idle land (Hook functions passed by name)
--- luacheck: globals flintley seller (NPC functions passed by name)
 
 function create ()
    -- Note: this mission makes no system claims.
@@ -63,14 +57,14 @@ function accept()
       misn.setReward(_("You weren't told!"))
       misn.setDesc(fmt.f(_("Baron Sauterfeldt has summoned you to his ship, which is in the {sys} system."), {sys=baronsys}))
       misn.osdCreate(_("Prince"), {
-         fmt.f(_("Fly to the {sys} system and dock with (board) Kahan Pinnacle"), {sys=baronsys}),
+         fmt.f(_("Fly to the {sys} system and dock with (board) Gauss Pinnacle"), {sys=baronsys}),
       })
       mem.marker = misn.markerAdd(baronsys, "low")
 
       mem.enterhook = hook.enter("enter")
    else
-      tk.msg(_("Sorry, not today"), _([["Okay, fair enough," the man says with a disappointed look on his face. "I'll try to find someone else. But maybe we'll run into each other again, so if you change your mind..."]]))
-      abort()
+      tk.msg(_("Sorry, not today"), _([["Okay, fair enough," the man says with a disappointed look on his face. "I'll try to find someone else. But maybe we'll run into each other again, so if you change your mind…"]]))
+      return
    end
 end
 
@@ -83,7 +77,7 @@ function board()
     "I should warn you, {wrongname2}. Some of my, ah, colleagues have also set their sights on this item, and so you can expect their henchmen to try to take it off you. I trust you are equipped to defend yourself against their despicable sort."]]), {wrongname1=mangle(player.name()), pnt=flintplanet, sys=flintsys, wrongname2=mangle(player.name())}))
       tk.msg(_("Off to the shops"), _([[You are swiftly escorted back to your ship. You didn't really get the chance to ask the Baron any questions, such as who these potential attackers are, how you're supposed to pay for the artefacts once you locate the sellers, or what you will get out of all this. You do, however, find an update to your galaxy map that shows the location of the sellers, as well as a list of names and portraits. It would seem that the only way to find out what you're dealing with is the hard way.]]))
       misn.osdCreate(_("Prince"), {
-         fmt.f(_("Fly to the {sys} system and dock with (board) Kahan Pinnacle"), {sys=baronsys}),
+         fmt.f(_("Fly to the {sys} system and dock with (board) Gauss Pinnacle"), {sys=baronsys}),
          _("Buy the artefact and take it to Flintley"),
       })
       misn.setDesc(_("Baron Sauterfeldt has tasked you with finding an ancient artefact, but he doesn't know exactly where to get it."))
@@ -124,13 +118,13 @@ end
 
 function land()
    local sellerdesc = _("You spot a dodgy individual who matches one of the portraits in your ship's database. This must be one of the artefact sellers.")
-   if planet.cur() == artefactplanetA and not mem.artifactA then
+   if spob.cur() == artefactplanetA and not mem.artifactA then
       mem.sellnpc = misn.npcAdd("seller", _("Artefact seller"), portrait.get("Pirate"), sellerdesc, 4)
-   elseif planet.cur() == artefactplanetB and not mem.artifactB then
+   elseif spob.cur() == artefactplanetB and not mem.artifactB then
       mem.sellnpc = misn.npcAdd("seller", _("Artefact seller"), portrait.get("Pirate"), sellerdesc, 4)
-   elseif planet.cur() == artefactplanetC and not mem.artifactC then
+   elseif spob.cur() == artefactplanetC and not mem.artifactC then
       mem.sellnpc = misn.npcAdd("seller", _("Artefact seller"), portrait.get("Pirate"), sellerdesc, 4)
-   elseif planet.cur() == flintplanet then
+   elseif spob.cur() == flintplanet then
       if mem.flintleyfirst then
          misn.npcAdd("flintley", _("A reedy-looking man"), "neutral/unique/flintley.webp", _("You spot a thin, nervous looking individual. He does not seem to want to be here. This could be that Flintley fellow the Baron told you about."), 4)
       else
@@ -178,7 +172,7 @@ function flintley()
          bingo = true
       else
          tk.msg(_("This is not the artefact you're looking for"), fmt.f(_([[Flintley studies the object on the table for a while, checking the online database a number of times in the process. Then, finally, he turns to you. "I hate to say this, but it seems you've bought a counterfeit. It's a good one, though! That seller on {pnt} must have known his stuff. You see, this is very similar to a number plate used by hovercars on Mars at the time of the Second Growth. However, it's missing a number of vital characteristics, and some details betray its recent manufacture. Close, {player}, close. But no cigar."
-    You dispose of the counterfeit artefact. Hopefully the next one will be what Sauterfeldt is looking for...]]), {pnt=artefactplanetC, player=player.name()}))
+    You dispose of the counterfeit artefact. Hopefully the next one will be what Sauterfeldt is looking for…]]), {pnt=artefactplanetC, player=player.name()}))
          mem.artifactsfound = mem.artifactsfound + 1
       end
       misn.cargoRm(mem.artifactC)
@@ -191,7 +185,7 @@ function flintley()
     "It's called a skate-board," Flintley continues. "The records about it are a bit sketchy and a lot is nothing but conjecture, but it appears it was once used in primitive communal rituals. The exact nature of these rituals is unknown, but they may have been tribal initiations or even mating rituals. The patterns in the board itself are thought to have a spiritual or mystical meaning. Also, according to some theories, people used to stand on top of the skate-board, with the cylinder wheels facing the ground. This has led some historians to believe that the feet were once central to human psychology."
     Flintley seems to have a lot more to say on the subject, but you're not that interested, so you thank him and return to your ship with the ancient artefact. You can only hope that the Baron is as enthusiastic about this skate-board as his historian!]]), {player=player.name()}))
       misn.osdCreate(_("Prince"), {
-         fmt.f(_("Fly to the {sys} system and dock with (board) Kahan Pinnacle"), {sys=baronsys}),
+         fmt.f(_("Fly to the {sys} system and dock with (board) Gauss Pinnacle"), {sys=baronsys}),
          _("Buy the artefact and take it to Flintley"),
          _("Take the artefact to Baron Sauterfeldt"),
       })
@@ -212,7 +206,7 @@ end
 function seller()
    local option_yes = fmt.f(_("Buy the artefact ({credits})"), {credits=fmt.credits(reward * 0.15)})
    local option_no = _("Don't buy the artefact")
-   if planet.cur() == artefactplanetA then
+   if spob.cur() == artefactplanetA then
       if tk.choice(_("A suspicious salesman"), _([["Hello there," the guy says to you when you approach. "Can I interest you in this bona fide relic from an ancient past? Unlike all those scammers out there, I offer you the real deal, no fakes here!"]]), option_yes, option_no) == 1 then
          if player.credits() >= reward * 0.15 then
             misn.npcRm(mem.sellnpc)
@@ -224,7 +218,7 @@ function seller()
             tk.msg(_("Not enough money!"), fmt.f(_("You can't currently afford to buy this artefact. You need {credits}."), {credits=fmt.credits(reward * 0.15)}))
          end
       end
-   elseif planet.cur() == artefactplanetB then
+   elseif spob.cur() == artefactplanetB then
       if tk.choice(_("A suspicious salesman"), _([[The man grins at you. "Ah, I can tell you have the eye of a connoisseur! I deal only in the finest, counterfeit-free antiques. If you're smart, and I can see that you are, you won't trust all those opportunists who will try to sell you fakes! How about it?"]]), option_yes, option_no) == 1 then
          if player.credits() >= reward * 0.15 then
             misn.npcRm(mem.sellnpc)
@@ -236,7 +230,7 @@ function seller()
             tk.msg(_("Not enough money!"), fmt.f(_("You can't currently afford to buy this artefact. You need {credits}."), {credits=fmt.credits(reward * 0.15)}))
          end
       end
-   elseif planet.cur() == artefactplanetC then
+   elseif spob.cur() == artefactplanetC then
       if tk.choice(_("A suspicious salesman"), _([[The woman beckons you over to the bar. "Listen, friend. I have here a unique, extremely rare remnant of prehistoric times. This is the genuine article, trust me on that. One hundred per cent legit! And you wouldn't want to spend good credits on a fake, right?"]]), option_yes, option_no) == 1 then
          if player.credits() >= reward * 0.15 then
             misn.npcRm(mem.sellnpc)
@@ -253,12 +247,12 @@ end
 
 function enter()
    if system.cur() == baronsys then
-      pinnacle = pilot.add("Proteron Kahan", "Independent", planet.get("Ulios"):pos() + vec2.new(-400,-400), _("Pinnacle"), {ai="trader"} )
+      pinnacle = pilot.add("Proteron Gauss", "Independent", spob.get("Ulios"):pos() + vec2.new(-400,-400), _("Pinnacle"), {ai="trader"} )
       pinnacle:setInvincible(true)
       pinnacle:setFriendly()
       pinnacle:control()
       pinnacle:setHilight(true)
-      pinnacle:moveto(planet.get("Ulios"):pos() + vec2.new( 500, -500), false, false)
+      pinnacle:moveto(spob.get("Ulios"):pos() + vec2.new( 500, -500), false, false)
       mem.idlehook = hook.pilot(pinnacle, "idle", "idle")
       mem.hhail = hook.pilot(pinnacle, "hail", "hail")
    elseif mem.artifactA ~= nil or mem.artifactB ~= nil or mem.artifactC ~= nil or mem.artifactReal ~= nil then
@@ -285,10 +279,10 @@ function enter()
 end
 
 function idle()
-   pinnacle:moveto(planet.get("Ulios"):pos() + vec2.new( 500,  500), false)
-   pinnacle:moveto(planet.get("Ulios"):pos() + vec2.new(-500,  500), false)
-   pinnacle:moveto(planet.get("Ulios"):pos() + vec2.new(-500, -500), false)
-   pinnacle:moveto(planet.get("Ulios"):pos() + vec2.new( 500, -500), false)
+   pinnacle:moveto(spob.get("Ulios"):pos() + vec2.new( 500,  500), false)
+   pinnacle:moveto(spob.get("Ulios"):pos() + vec2.new(-500,  500), false)
+   pinnacle:moveto(spob.get("Ulios"):pos() + vec2.new(-500, -500), false)
+   pinnacle:moveto(spob.get("Ulios"):pos() + vec2.new( 500, -500), false)
 end
 
 function hail()
