@@ -1,16 +1,12 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Dvaered Sabotage">
- <flags>
-  <unique />
- </flags>
- <avail>
-  <priority>2</priority>
-  <chance>20</chance>
-  <done>Dvaered Escort</done>
-  <location>Bar</location>
-  <faction>Dvaered</faction>
- </avail>
+ <unique />
+ <priority>2</priority>
+ <chance>20</chance>
+ <done>Dvaered Escort</done>
+ <location>Bar</location>
+ <faction>Dvaered</faction>
  <notes>
   <campaign>Frontier Invasion</campaign>
  </notes>
@@ -39,13 +35,14 @@ require "proximity"
 local fw = require "common.frontier_war"
 local fmt = require "format"
 local pir = require "common.pirate"
+local cinema = require "cinema"
 
 -- Mission constants
 local bombMass = 100
-local hampla, hamsys     = planet.getS("Stutee") --Morgan Station
-local sabotpla, sabotsys = planet.getS(fw.wlrd_planet)
-local duelpla, duelsys   = planet.getS("Dvaer Prime")
-local intpla, intsys     = planet.getS("Timu")
+local hampla, hamsys     = spob.getS("Stutee") --Morgan Station
+local sabotpla, sabotsys = spob.getS(fw.wlrd_planet)
+local duelpla, duelsys   = spob.getS("Dvaer Prime")
+local intpla, intsys     = spob.getS("Timu")
 
 -- Non-persistent state
 local p, ps -- active pilot/fleet
@@ -53,14 +50,12 @@ local battleaddict, battleaddict2, hamelsen, klank, klank2, leblanc, randguy, ta
 local mypos, step -- location and spacing of the duel, initialized with the above pilots
 
 local equipGoddard, player_civilian, release_baddies -- Forward-declared functions
--- luacheck: globals battleaddict_killed beginDuel disableDuel enter enter1_message enter2_message everyoneLands fighterDuel killing land meeting message moreSound1 moreSound2 phalanx_attacked phalanx_boarded phalanx_died phalanx_safe spawn_phalanx (Hook functions passed by name)
--- luacheck: globals endMisn hamfresser majorTam (NPC functions passed by name)
 
 -- common hooks
 message = fw.message
 
 function create()
-   if planet.cur() == hampla then
+   if spob.cur() == hampla then
       misn.finish(false)
    end
 
@@ -74,7 +69,7 @@ end
 function accept()
    if not tk.yesno( _("Ready for another mission?"), fmt.f(_([[You sit at Tam's table and wait for him to speak. "Hello, citizen {player}. You remember Lord Battleaddict, the old warlord who tried to kill us twice? I have good news: with a few other members of the Space Force, we've devised a way to make him regret what he did, and we need a civilian pilot, like you. Are you in?"]]), {player=player.name()}) ) then
       tk.msg(_("Refusal"), _([["Alight, citizen, see you later, then."]]))
-      misn.finish(false)
+      return
    end
    tk.msg(_("The plan"), _([["I knew you would accept!" Says Major Tam. "Here is the situation:
    "The general I am working for, General Klank, is in charge of... hem... in charge of a crucial operation the High Command wants to carry out. This operation will involve troops of the High Command, but also Warlords, including Battleaddict. The problem is that General Klank and Lord Battleaddict disagree on everything about this plan. As a consequence, they are going to have a Goddard duel, which is usually how two important Dvaered generals settle deep disagreements."]]))
@@ -96,18 +91,18 @@ function accept()
 end
 
 function land()
-   if mem.stage == 0 and planet.cur() == hampla then -- Meet Captain Hamfresser
+   if mem.stage == 0 and spob.cur() == hampla then -- Meet Captain Hamfresser
       misn.npcAdd("hamfresser", _("Captain Hamfresser"), fw.portrait_hamfresser, _("A tall, and very large, cyborg soldier sits against a wall, right next to the emergency exit. He loudly drinks an orange juice through a pink straw and suspiciously examines the other customers. By the power of his glare he cleared a large area around him as people seem to prefer to move away instead of meeting his half-robotic gaze. Unfortunately, he matches the description of your contact, which means you will have to overcome your fear and talk to him."))
 
    elseif mem.stage == 2 then -- The player landed somewhere on Battleaddict's system
       tk.msg( _("What are you doing here?"), _("This planet belongs to Lord Battleaddict. You will be captured if you land here. The mission failed.") )
       misn.finish(false)
 
-   elseif mem.stage == 5 and planet.cur() == duelpla then -- Report back
+   elseif mem.stage == 5 and spob.cur() == duelpla then -- Report back
       misn.npcAdd("majorTam", _("Major Tam and Captain Leblanc"), fw.portrait_tam, _("Major Tam and Captain Leblanc seem to be waiting for you."))
       misn.npcAdd("majorTam", _("Major Tam and Captain Leblanc"), fw.portrait_leblanc, _("Major Tam and Captain Leblanc seem to be waiting for you."))
 
-   elseif mem.stage == 7 and planet.cur() == duelpla then -- Epilogue
+   elseif mem.stage == 7 and spob.cur() == duelpla then -- Epilogue
       misn.npcAdd("endMisn", _("Your employers"), fw.portrait_tam, _("Tam and Leblanc are congratulating their general."))
       misn.npcAdd("endMisn", _("Your employers"), fw.portrait_leblanc, _("Tam and Leblanc are congratulating their general."))
       misn.npcAdd("endMisn", _("Your employers"), fw.portrait_klank, _("Tam and Leblanc are congratulating their general."))
@@ -194,12 +189,12 @@ function enter()
 
       klank = pilot.add( "Dvaered Goddard", "Dvaered", mypos + vec2.new(-step, step/2), _("General Klank") )
       klank:control(true)
-      klank:setFaction("DHC")
+      klank:setFaction( fw.fct_dhc() )
       equipGoddard( klank, true ) -- Klank's superior equipment should ensure victory
 
       battleaddict = pilot.add( "Dvaered Goddard", "Dvaered", mypos + vec2.new(step, step/2), _("Lord Battleaddict") )
       battleaddict:control(true)
-      battleaddict:setFaction("Warlords")
+      battleaddict:setFaction( fw.fct_warlords() )
       equipGoddard( battleaddict, false )
 
       klank:face(battleaddict)
@@ -225,12 +220,12 @@ function enter()
       randguy:control(true)
       randguy:face(klank)
 
-      player.pilot():control()
-      player.pilot():moveto( mypos + vec2.new(0, -step/2) ) -- To avoid being in the range
-      player.cinematics( true, { gui = true } )
-      player.pilot():setInvincible()
+      local pp = player.pilot()
+      cinema.on{ gui = true }
+      pp:taskClear()
+      pp:moveto( mypos + vec2.new(0, -step/2) ) -- To avoid being in the range
 
-      camera.set( mypos + vec2.new(0, step/2) )
+      camera.set( mypos + vec2.new(0, step/2), true )
 
       hook.timer(5.0, "beginDuel")
       hook.timer(15.0, "disableDuel")
@@ -295,28 +290,31 @@ function killing()
 end
 
 function release_baddies()
-   warlord:setFaction("Warlords")
+   local fwarlords = fw.fct_warlords()
+   warlord:setFaction( fwarlords )
    warlord:control(false)
    for i, j in ipairs(ps) do
-      j:setFaction("Warlords")
+      j:setFaction( fwarlords )
    end
 end
 
 -- Test civilian ships
 function player_civilian()
-   local playerclass = player.pilot():ship():class()
-   return (playerclass == "Yacht" or playerclass == "Courier" or playerclass == "Freighter" or playerclass == "Armoured Transport")
+   local pps = player.pilot():ship()
+   local tags = pps:tags()
+   local playerclass = pps:class()
+   return (playerclass == "Yacht" or playerclass == "Courier" or tags.transport or playerclass == "Armoured Transport")
 end
 
 -- Spawn the Phalanx to disable
 function spawn_phalanx()
    p = pilot.add( "Dvaered Phalanx", "Dvaered", intpla, _("Gorgon") )
-   p:setFaction("Warlords")
+   p:setFaction(fw.fct_warlords())
    p:setHilight()
    p:control()
 
    mem.nextsys = lmisn.getNextSystem(system.cur(), sabotsys)
-   p:hyperspace( mem.nextsys ) -- Go towards Battleaddict's place
+   p:hyperspace( mem.nextsys, true ) -- Go towards Battleaddict's place
 
    p:outfitRm("all")
    p:outfitRm("cores")
@@ -364,7 +362,7 @@ function phalanx_boarded()
    misn.cargoRm(mem.bomblet)
 
    player.unboard() -- Prevent the player form actually boarding the ship
-   p:setFaction("DHC")
+   p:setFaction( fw.fct_dhc() )
    p:control(true)
    p:taskClear()
    p:hyperspace( mem.nextsys )
@@ -430,7 +428,7 @@ function disableDuel()
    hook.timer( 2.0, "message", {pilot = tam, msg = _("Damn!")} )
    hook.timer( 4.0, "message", {pilot = leblanc, msg = _("Oooooo...")} )
    hook.timer( 6.0, "message", {pilot = hamelsen, msg = _("What the?")} )
-   hook.timer( 8.0, "message", {pilot = randguy, msg = _("Come on!")} )
+   hook.timer( 8.0, "message", {pilot = randguy, msg = p_("fw01", "Come on!")} )
 
    hook.timer( 11.0, "message", {pilot = tam, msg = _("Hey, they have put a bomb in the general's ship as well!")} )
    hook.timer( 15.0, "message", {pilot = leblanc, msg = _("The electricians! We've called electricians recently! They planted the bomb!")} )
@@ -455,12 +453,12 @@ end
 function fighterDuel()
    klank2 = pilot.add( "Dvaered Vendetta", "Dvaered", klank:pos(), _("General Klank") )
    klank2:control(true)
-   klank2:setFaction("DHC")
+   klank2:setFaction( fw.fct_dhc() )
    fw.equipVendettaMace( klank2 ) -- Klank's superior equipment should ensure victory once more
 
    battleaddict2 = pilot.add( "Dvaered Vendetta", "Dvaered", battleaddict:pos(), _("Lord Battleaddict") )
    battleaddict2:control(true)
-   battleaddict2:setFaction("Warlords")
+   battleaddict2:setFaction( fw.fct_warlords() )
 
    battleaddict2:broadcast( _("Shall we continue?") )
    hook.timer( 1.0, "message", {pilot = klank2, msg = _("Of course, we shall!")} )
@@ -486,7 +484,7 @@ function fighterDuel()
    klank2:attack(battleaddict2)
    hook.pilot( battleaddict2, "exploded", "battleaddict_killed" )
 
-   --camera.set(klank2)
+   --camera.set(klank2, true)
 end
 
 function battleaddict_killed()
@@ -497,10 +495,8 @@ function battleaddict_killed()
    urnus:broadcast( _("General Klank won the duel!") )
 
    hook.timer( 2.0, "everyoneLands" )
-   camera.set()
-   player.pilot():control( false )
-   player.cinematics( false )
-   player.pilot():setInvincible( false )
+   camera.set( nil, true )
+   cinema.off()
 
    mem.stage = 7
    misn.osdActive(2)
