@@ -1,16 +1,12 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Minerva Pirates 3">
- <flags>
-  <unique />
- </flags>
- <avail>
-  <priority>4</priority>
-  <chance>100</chance>
-  <location>Bar</location>
-  <planet>Minerva Station</planet>
-  <done>Minerva Pirates 2</done>
- </avail>
+ <unique />
+ <priority>4</priority>
+ <chance>100</chance>
+ <location>Bar</location>
+ <spob>Minerva Station</spob>
+ <done>Minerva Pirates 2</done>
  <notes>
   <campaign>Minerva</campaign>
   <provides name="Spa Propaganda" />
@@ -53,8 +49,6 @@ local mainsys = system.get("Limbo")
 --    7. defend torture ship
 mem.misn_state = nil
 local harper -- Non-persistent state
--- luacheck: globals enter generate_npc harper_board harper_death harper_gotattacked harper_hail harper_land start_spa (Hook functions passed by name)
--- luacheck: globals approach_pir approach_spa (NPC functions passed by name)
 
 function create ()
    if not misn.claim( mainsys ) then
@@ -85,7 +79,7 @@ function accept ()
 end
 
 function generate_npc ()
-   if planet.cur() == planet.get("Minerva Station") then
+   if spob.cur() == spob.get("Minerva Station") then
       misn.npcAdd( "approach_pir", minerva.pirate.name, minerva.pirate.portrait, minerva.pirate.description )
       if mem.misn_state == 4 then
          mem.npc_spa = misn.npcAdd( "approach_spa", _("Minerva Station Spa"), spa_portrait, spa_description )
@@ -137,7 +131,7 @@ function approach_pir ()
          misn.osdCreate( _("Minerva Moles"),
                {_("Plant a listening device in a VIP room.") } )
 
-         local minsta = planet.get("Minerva Station")
+         local minsta = spob.get("Minerva Station")
          misn.markerAdd( minsta )
 
          minerva.log.pirate(_("You accepted another job from the sketchy individual to uncover moles at Minerva Station.") )
@@ -197,6 +191,7 @@ She takes out a metallic object from her pocket and show it to you. You don't kn
    pir(_([["The high-tech latest gen signal capturing device I gave should be able to bypass most jammers. However, you're going to have to plant it in a VIP room or in some place where we might be able to catch the mole."]]))
    if mem.misn_state==0 then
       pir(_([["The main issue we have right now is that VIP rooms and such are not easy to access, so we're going to have to keep our eyes open and see if we can spot an opportunity to plant the device."]]))
+      pir(_([["You never know when we'll get a chance, just take your time doing stuff near Minerva station and I'm sure you'll find an opening."]]))
    elseif mem.misn_state==1 then
       pir(_([["The Spa sounds like a perfect place to set up the signal capturing device. Nobody will suspect a thing! You should buy a ticket to the Spa and see if we can get lucky. If not, we may have to take other measures to ensure success."]]))
    elseif mem.misn_state==3 then
@@ -273,10 +268,10 @@ function enter ()
       -- Don't stop spawns, but claimed in case something else stops spawns
       -- TODO maybe add Minerva patrols that aggro ta make it a bit harder?
       -- Spawn Harper Bowdoin and stuff
-      local pos = planet.get("Minerva Station"):pos() + vec2.newP( 5000, rnd.angle() )
+      local pos = spob.get("Minerva Station"):pos() + vec2.newP( 5000, rnd.angle() )
 
       local fharper = faction.dynAdd( nil, "Harper Bowdoin" )
-      harper = pilot.add( "Quicksilver", fharper, pos, "Harper", {ai="civilian"} )
+      harper = pilot.add( "Quicksilver", fharper, pos, _("Harper"), {ai="civilian"} )
       local aimem = harper:memory()
       aimem.loiter = math.huge -- Should make them loiter forever
       aimem.distress = false -- Don't distress or everyone aggros
@@ -341,12 +336,12 @@ end
 
 
 function harper_gotattacked( _plt, attacker )
-   if attacker == player.pilot() then
+   if attacker and attacker:withPlayer() then
       if not mem.harper_attacked then
          -- Run to land at the station
          harper:setNoLand(false)
          harper:control()
-         harper:land( planet.get("Minerva Station") )
+         harper:land( spob.get("Minerva Station") )
          mem.harper_attacked = true
       end
 
@@ -388,7 +383,7 @@ function harper_hail ()
       -- He goes land now
       harper:setNoLand(false)
       harper:control()
-      harper:land( planet.get("Minerva Station") )
+      harper:land( spob.get("Minerva Station") )
    end
 
    if mem.harper_almostdied then
@@ -411,7 +406,7 @@ He gulps.
             vn.jump("broke")
          end
       end )
-      h(_([["Actually, swimming in a chicken sounds like a bit of a drag. I think I might be allergic them anyway."
+      h(_([["Actually, swimming with a chicken sounds like a bit of a drag. I think I might be allergic to them anyway."
 He coughs nervously.]]))
       vn.sfxMoney()
       vn.func( function ()
@@ -542,7 +537,7 @@ He scoffs at you and closes the transmission.]]))
          vn.jump("broke")
       end
    end )
-   h(_([["Actually, swimming in a chicken sounds like a bit of a drag. I think I might be allergic them anyway."]]))
+   h(_([["Actually, swimming with a chicken sounds like a bit of a drag. I think I might be allergic to them anyway."]]))
    vn.sfxMoney()
    vn.func( function ()
       _harper_done()
@@ -554,7 +549,7 @@ He scoffs at you and closes the transmission.]]))
    vn.jump("leave")
 
    vn.label("money_tkn")
-   h(_([["Actually, swimming in a chicken sounds like a bit of a drag. I think I might be allergic them anyway."]]))
+   h(_([["Actually, swimming with a chicken sounds like a bit of a drag. I think I might be allergic to them anyway."]]))
    vn.sfxMoney()
    vn.func( function ()
       _harper_done()
