@@ -1,16 +1,12 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Minerva Pirates 5">
- <flags>
-  <unique />
- </flags>
- <avail>
-  <priority>4</priority>
-  <chance>100</chance>
-  <location>Bar</location>
-  <planet>Minerva Station</planet>
-  <done>Minerva Pirates 4</done>
- </avail>
+ <unique />
+ <priority>4</priority>
+ <chance>100</chance>
+ <location>Bar</location>
+ <spob>Minerva Station</spob>
+ <done>Minerva Pirates 4</done>
  <notes>
   <campaign>Minerva</campaign>
  </notes>
@@ -31,6 +27,7 @@ local minerva = require "common.minerva"
 local vn = require 'vn'
 local equipopt = require 'equipopt'
 local fmt = require "format"
+local pilotai = require "pilotai"
 
 local reward_amount = minerva.rewards.pirate5
 local drone_control_update -- Forward-declared functions
@@ -43,8 +40,6 @@ local mainsys = system.get("Gammacron")
 --    3. hacking center disabled
 mem.misn_state = nil
 local all_ships, drone_control1, drone_control2, drone_group1, drone_group2, hacking_center, main_boss -- Non-persistent state
--- luacheck: globals blowup drone_control1_dead drone_control2_dead enter generate_npc hacking_center_dead message_first message_hostile message_warn plant_explosives (Hook functions passed by name)
--- luacheck: globals approach_zuri (NPC functions passed by name)
 
 
 function create ()
@@ -84,7 +79,7 @@ function accept ()
 end
 
 function generate_npc ()
-   if planet.cur() == planet.get("Minerva Station") then
+   if spob.cur() == spob.get("Minerva Station") then
       misn.npcAdd( "approach_zuri", minerva.zuri.name, minerva.zuri.portrait, minerva.zuri.description )
    end
 end
@@ -304,9 +299,7 @@ function enter ()
          local p = spawn_drone( s, pos )
          if k==1 then
             l = p
-            local aimem = p:memory()
-            aimem.waypoints = route
-            aimem.loiter = math.huge -- patrol forever
+            pilotai.patrol( p, route )
          else
             p:setLeader( l )
          end
@@ -454,8 +447,8 @@ function drone_control_update ()
    end
 end
 function hacking_center_dead ()
-   misn.markerMove( mem.mrk_mainsys, planet.get("Minerva Station") )
+   misn.markerMove( mem.mrk_mainsys, spob.get("Minerva Station") )
    misn.osdActive(3)
    mem.misn_state = 3
-   player.msg("#gThe hacking centre has been destroyed!#0")
+   player.msg("#g".._("The hacking centre has been destroyed!").."#0")
 end
