@@ -1,20 +1,18 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Seek And Destroy">
- <avail>
-  <priority>4</priority>
-  <cond>player.numOutfit("Mercenary License") &gt; 0</cond>
-  <chance>875</chance>
-  <location>Computer</location>
-  <faction>Dvaered</faction>
-  <faction>Empire</faction>
-  <faction>Frontier</faction>
-  <faction>Goddard</faction>
-  <faction>Independent</faction>
-  <faction>Sirius</faction>
-  <faction>Soromid</faction>
-  <faction>Za'lek</faction>
- </avail>
+ <priority>4</priority>
+ <cond>player.numOutfit("Mercenary License") &gt; 0</cond>
+ <chance>875</chance>
+ <location>Computer</location>
+ <faction>Dvaered</faction>
+ <faction>Empire</faction>
+ <faction>Frontier</faction>
+ <faction>Goddard</faction>
+ <faction>Independent</faction>
+ <faction>Sirius</faction>
+ <faction>Soromid</faction>
+ <faction>Za'lek</faction>
  <notes>
   <tier>3</tier>
  </notes>
@@ -38,8 +36,6 @@ local lmisn = require "lmisn"
 
 local trigger_ambush, spawn_advisor, space_clue, next_sys -- Forward-declared functions
 local adm_factions, advisor, ambush, hailed, target_ship -- Non-persistent state
--- luacheck: globals ambust_msg clue_attacked enter hail hail_ad hailme land player_flee target_death target_flee target_land (Hook functions passed by name)
--- luacheck: globals clue_bar (NPC functions passed by name)
 
 local quotes = {}
 local comms = {}
@@ -123,7 +119,7 @@ quotes.pay[2] = _("No one will miss this outlaw pilot! The bounty has been depos
 mem.osd_msg    = {}  -- 3-part OSD: Search a system, do the deed, get paid.
 
 function create ()
-   mem.paying_faction = planet.cur():faction()
+   mem.paying_faction = spob.cur():faction()
 
    -- Choose the target faction among Pirate and FLF
    adm_factions = {faction.get("Pirate"), faction.get("FLF")}
@@ -188,25 +184,31 @@ function create ()
    mem.tgtship = ships[rnd.rnd(1,#ships)]
    mem.credits = 1e6 + rnd.rnd()*500e3
    mem.cursys = 1
+   -- Faction prefix
+   local prefix
+   if mem.paying_faction:static() then
+      prefix = ""
+   else
+      prefix = require("common.prefix").prefix(mem.paying_faction)
+   end
 
    -- Set mission details
-   misn.setTitle( fmt.f( _("Seek And Destroy Mission, starting in {sys}"), {sys=mem.mysys[1]} ) )
-   misn.setDesc( fmt.f( _("The {target_faction} pilot known as {plt} is wanted dead or alive by {paying_faction} authorities. He was last seen in the {sys} system."),
-         {target_faction=mem.target_faction, plt=mem.name, paying_faction=mem.paying_faction, sys=mem.mysys[1]} ) )
+   misn.setTitle(prefix..fmt.f( _("Seek And Destroy Mission, starting in {sys}"), {sys=mem.mysys[1]} ) )
+   local desc = fmt.f(_([[The {target_faction} pilot known as {plt} is wanted dead or alive by {paying_faction} authorities. They were last seen in the {sys} system.
+
+#nTarget:#0 {plt} ({shipclass}-class ship)
+#nWanted:#0 Dead or Alive
+#nLast Seen:#0 {sys} system]]),
+         {target_faction=mem.target_faction, plt=mem.name, paying_faction=mem.paying_faction, sys=mem.mysys[1], shipclass=_(ship.get(mem.aship):classDisplay())} )
+   if not mem.paying_faction:static() then
+      desc = desc.."\n"..fmt.f(_([[#nReputation Gained:#0 {fct}]]),
+         {fct=mem.paying_faction})
+   end
+   misn.setDesc(desc)
    misn.setReward( fmt.credits( mem.credits ) )
    mem.marker = misn.markerAdd( mem.mysys[1], "computer" )
 end
 
--- Test if an element is in a list
-local function elt_inlist( elt, list )
-   for i, elti in ipairs(list) do
-      if elti == elt then
-         return true
-      end
-   end
-   return false
-end
-
 function accept ()
    misn.accept()
 
@@ -348,6 +350,7 @@ function hail_ad()
    hook.rm(mem.hailie)
    hook.rm(mem.hailie2)
    tk.msg( _("You're looking for someone"), _([["Hi there", says the pilot. "You seem to be lost." As you explain that you're looking for an outlaw pilot and have no idea where to find your target, the pilot laughs. "So, you've taken a Seek and Destroy job, but you have no idea how it works. Well, there are two ways to get information on an outlaw: first way is to land on a planet and ask questions at the bar. The second way is to ask pilots in space. By the way, pilots of the same faction as your target are most likely to have information, but won't give it easily. Good luck with your task!"]]) ) -- Give advice to the player
+   player.commClose()
 end
 
 -- Player hails a ship for info
@@ -357,7 +360,7 @@ function hail( target )
       return
    end
 
-   if system.cur() == mem.mysys[mem.cursys] and mem.stage == 0 and not elt_inlist( target, hailed ) then
+   if system.cur() == mem.mysys[mem.cursys] and mem.stage == 0 and not inlist( hailed, target ) then
       hailed[#hailed+1] = target -- A pilot can be hailed only once
 
       if mem.cursys+1 >= mem.nbsys then -- No more claimed system : need to finish the mission
@@ -490,8 +493,7 @@ end
 -- Player attacks an informant who has refused to give info
 function clue_attacked( p, attacker )
    -- Target was hit sufficiently to get more talkative
-   if (attacker == player.pilot() or attacker:leader() == player.pilot())
-         and p:health() < 100 then
+   if attacker and attacker:withPlayer() and p:health() < 100 then
       p:control()
       p:runaway(player.pilot())
       tk.msg( _("You're intimidating!"), fmt.f( quotes.scared[rnd.rnd(1,#quotes.scared)], {plt=mem.name, sys=mem.mysys[mem.cursys+1]} ) )
@@ -519,7 +521,7 @@ function land()
       mem.mynpc = misn.npcAdd("clue_bar", _("Shifty Person"), portrait.get("Pirate"), _("This person might be an outlaw, a pirate, or even worse, a bounty hunter. You normally wouldn't want to get close to this kind of person, but they may be a useful source of information."))
 
    -- Player wants to be paid
-   elseif planet.cur():faction() == mem.paying_faction and mem.stage == 4 then
+   elseif spob.cur():faction() == mem.paying_faction and mem.stage == 4 then
       tk.msg( _("Good work, pilot!"), quotes.pay[rnd.rnd(1,#quotes.pay)] )
       player.pay( mem.credits )
       mem.paying_faction:modPlayerSingle( rnd.rnd(1,2) )
