@@ -1,13 +1,11 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Sirius Pilgrimage Transport">
- <avail>
-  <priority>3</priority>
-  <chance>266</chance>
-  <cond>faction.playerStanding("Sirius") &gt; 5</cond>
-  <location>Computer</location>
-  <faction>Sirius</faction>
- </avail>
+ <priority>3</priority>
+ <chance>266</chance>
+ <cond>faction.playerStanding("Sirius") &gt; 5</cond>
+ <location>Computer</location>
+ <faction>Sirius</faction>
  <notes>
   <tier>1</tier>
  </notes>
@@ -36,13 +34,12 @@
 -- All missions can be made in a Fidelity with an afterburner
 --
 --]]
-
 local car = require "common.cargo"
 local fmt = require "format"
+local srs = require "common.sirius"
 
--- luacheck: globals land tick (Hook functions passed by name)
 
-local dest_planet, dest_sys = planet.getS("Mutris")
+local dest_planet, dest_sys = spob.getS("Mutris")
 
 -- passenger rank
 local prank = {}
@@ -83,7 +80,7 @@ ferry_land_p3[2] = _("{passenger} tersely expresses their displeasure with the l
 
 -- Customization of car.calculateRoute in common.cargo
 local function ferry_calculateRoute (dplanet, dsys)
-    mem.origin_p, mem.origin_s = planet.cur()
+    mem.origin_p, mem.origin_s = spob.cur()
     local routesys = mem.origin_s
     local routepos = mem.origin_p:pos()
 
@@ -119,7 +116,7 @@ function create()
        misn.finish(false)
     end
 
-    mem.origin_p, mem.origin_s = planet.cur()
+    mem.origin_p, mem.origin_s = spob.cur()
     if mem.origin_s == dest_sys then
        misn.finish(false)
     end
@@ -145,8 +142,8 @@ function create()
         allowance = allowance + math.floor((mem.numjumps-1) / jumpsperstop) * stuperjump
     end
 
-    mem.timelimit  = time.get() + time.create(0, 0, allowance)
-    mem.timelimit2 = time.get() + time.create(0, 0, allowance * 1.3)
+    mem.timelimit  = time.get() + time.new(0, 0, allowance)
+    mem.timelimit2 = time.get() + time.new(0, 0, allowance * 1.3)
 
     -- Choose mission reward. This depends on the priority and the passenger rank.
     local jumpreward = 15e3
@@ -158,7 +155,7 @@ function create()
     mem.distbonus_minjumps = 5 -- This is the minimum distance needed to get a reputation bonus. Distances less than this don't incur a bonus.
 
     misn.markerAdd(mem.destplanet, "computer")
-    misn.setTitle( fmt.f(_("SR: {tier} pilgrimage transport for {rank}-class citizen"), {tier=ferrytime[mem.print_speed], rank=prank[mem.rank]}) )
+    misn.setTitle( fmt.f(srs.prefix.._("{tier} pilgrimage transport for {rank}-class citizen"), {tier=ferrytime[mem.print_speed], rank=prank[mem.rank]}) )
     car.setDesc( fmt.f(_("{tier} space transport to {pnt} for {rank}-class citizen"), {tier=ferrytime[mem.print_speed], pnt=mem.destplanet, rank=prank[mem.rank]}), nil, nil, mem.destplanet, mem.timelimit )
     misn.setReward(fmt.credits(mem.reward))
 
@@ -188,7 +185,7 @@ function accept()
         if not tk.yesno( _("Too slow"), fmt.f(_([[The passenger requests arrival within {time_limit}, but it will take at least {time} for your ship to reach {pnt}, missing the deadline.
 
 Accept the mission anyway?]]), {time_limit=(mem.timelimit - time.get()), time=(playerbest - time.get()), pnt=mem.destplanet}) ) then
-            misn.finish()
+            return
         end
     end
 
@@ -200,7 +197,7 @@ Accept the mission anyway?]]), {time_limit=(mem.timelimit - time.get()), time=(p
 
         local counter = 0
         local altplanets = {}
-        for key,dplanet in ipairs( mem.destsys:planets() ) do
+        for key,dplanet in ipairs( mem.destsys:spobs() ) do
             if dplanet:canLand() then
                 counter = counter + 1
                 altplanets[counter] = dplanet
@@ -209,8 +206,8 @@ Accept the mission anyway?]]), {time_limit=(mem.timelimit - time.get()), time=(p
 
         if counter == 0 then
             -- Something has changed with the system map, and this mission is no longer valid
-            print( _("Error: no landable planets in the Aesir system. This mission is broken.\n") )
-            misn.finish()
+            print( _("Error: no landable planets in the Aesir system. This mission is broken.") )
+            return
         end
 
         mem.altdest = rnd.rnd(1,counter)
@@ -245,7 +242,7 @@ Accept the mission anyway?]]), {time_limit=(mem.timelimit - time.get()), time=(p
             tk.msg(_("Deficient clearance"), no_clearance_p1 .. no_clearance_text)
         end
         if not ok then
-            misn.finish()
+            return
         end
 
         mem.destplanet = altplanets[mem.altdest]
@@ -262,16 +259,16 @@ Accept the mission anyway?]]), {time_limit=(mem.timelimit - time.get()), time=(p
         if picky > 2 then
             -- Demands to be delivered in a Sirian ship
             tk.msg(_("Transportation details"), _("As you arrive at the hangar, the Sirian looks at your ship and remarks, \"What? This is to be the ship for my pilgrimage? This is unacceptable - such a crude ship must not be allowed to touch the sacred soil of Mutris. I will wait for a pilot who can ferry me in a true Sirian vessel.\""))
-            misn.finish()
+            return
         elseif picky > 0 then
             -- Could be persuaded, for a discount
             mem.reward = mem.reward*0.6666
             if not tk.yesno(_("Transportation details"), fmt.f(_("As you arrive at the hangar, the Sirian looks at your ship and remarks, \"Oh, you didn't tell me your ship is not from our native Sirian shipyards. Since that is the case, I would prefer to wait for another pilot. A pilgrimage is a sacred matter, and the vessel should be likewise.\"\nThe Sirian looks like they might be open to negotiating, however. Would you offer to fly the mission for {credits}?"), {credits=fmt.credits(mem.reward)})) then
-                misn.finish() -- Player won't offer a discount
+                return -- Player won't offer a discount
             end
             if picky > 1 then
                 tk.msg(_("Offer denied"), _("\"I'm sorry. Your price is reasonable, but piety is of greater value.\""))
-                misn.finish() -- Would not be persuaded by a discount
+                return -- Would not be persuaded by a discount
             else
                 tk.msg(_("Offer accepted"), _("\"Very well. For a price that reasonable, I will adjust my expectations.\""))  -- discount is ok
             end
@@ -291,12 +288,12 @@ Accept the mission anyway?]]), {time_limit=(mem.timelimit - time.get()), time=(p
     misn.cargoAdd(c, 0)  -- We'll assume you can hold as many pilgrims as you want?
     tick()
     hook.land("land")
-    hook.date(time.create(0, 0, 100), "tick") -- 100STU per tick
+    hook.date(time.new(0, 0, 100), "tick") -- 100STU per tick
 end
 
 -- Land hook
 function land()
-    if planet.cur() == mem.destplanet then
+    if spob.cur() == mem.destplanet then
 
         -- Check if we're still flying a Sirian ship
         mem.has_sirian_ship = player_has_sirian_ship()
