@@ -1,10 +1,16 @@
+local audio = require 'love.audio'
+local luaspfx = require 'luaspfx'
+
 local masslimit = 800^2 -- squared
 local jumpdist = 500
 local cooldown = 8
 
-function init( _p, po )
+local sfx = audio.newSource( 'snd/sounds/blink.ogg' )
+
+function init( p, po )
    po:state("off")
    mem.timer = 0
+   mem.isp = (p == player.pilot())
 end
 
 function update( _p, po, dt )
@@ -30,10 +36,16 @@ function ontoggle( p, po, on )
    if m > masslimit then
       dist = dist * masslimit / m
    end
-   -- TODO add energy cost and SPFX?
-   p:setPos( p:pos() + vec2.newP( dist, p:dir() ) )
-   mem.timer = cooldown
+   local pos = p:pos()
+   luaspfx.blink( pos ) -- Blink afterimage
+   p:effectAdd( "Blink" ) -- Cool "blink in" effect
+   p:setPos( pos + vec2.newP( dist, p:dir() ) )
+   mem.timer = cooldown * p:shipstat("cooldown_mod",true)
    po:state("cooldown")
    po:progress(1)
+
+   -- Play the sound
+   luaspfx.sfx( pos, p:vel(), sfx )
+
    return true
 end
