@@ -5,6 +5,8 @@
 --]]
 local optimize = {}
 local eparams = require 'equipopt.params'
+local bioship = require 'bioship'
+local ai_setup = require "ai.core.setup"
 local function choose_one( t ) return t[ rnd.rnd(1,#t) ] end
 
 -- Create caches and stuff
@@ -76,14 +78,20 @@ local goodness_override = {
 
 -- Special weights
 local goodness_special = {
-   ["Unicorp Medusa Launcher"] = 0.5,
+   ["Black Cat Doll"] = 0.25, -- Only active when stealthing
    ["TeraCom Mace Launcher"] = 0.5,
-   ["Unicorp Mace Launcher"] = 0.5,
    ["Enygma Systems Huntsman Launcher"] = 0.5,
    ["Enygma Systems Spearhead Launcher"] = 0.4, -- high damage but shield only
    ["TeraCom Medusa Launcher"] = 0.5,           -- really high disable
    ["Droid Repair Crew"] = 0.5, -- Only work until 50%
    ["Electron Burst Cannon"] = 0.7, -- Shieldbreaker damage
+   -- Plasma do a lot of damage over time
+   ["Plasma Blaster MK1"] = 1 / 0.75,
+   ["Plasma Blaster MK2"] = 1 / 0.75,
+   ["Plasma Cannon"] = 1 / 0.75,
+   ["Plasma Cluster Cannon"] = 1 / 0.75,
+   ["Plasma Turret MK1"] = 1 / 0.75,
+   ["Plasma Turret MK2"] = 1 / 0.75,
 }
 
 
@@ -103,35 +111,19 @@ special_ships["Drone"] = function( p )
       p:outfitAdd( o, 1, true )
    end
 end
-special_ships["Drone (Hyena)"] = special_ships["Drone"]
 special_ships["Heavy Drone"] = function( p )
    for k,o in ipairs{
-      "Milspec Orion 3701 Core System",
+      "Milspec Thalos 3602 Core System",
       "Unicorp Hawk 350 Engine",
       choose_one{"Nexus Light Stealth Plating", "S&K Light Combat Plating"},
       "Shatterer Launcher",
       "Shatterer Launcher",
-      "Neutron Disruptor",
-      "Neutron Disruptor",
+      "Heavy Neutron Disruptor",
+      "Heavy Neutron Disruptor",
    } do
       p:outfitAdd( o, 1, true )
    end
 end
-special_ships["Za'lek Scout Drone"] = function( p )
-   p:outfitAdd( "Particle Lance")
-end
-special_ships["Za'lek Light Drone"] = function( p )
-   p:outfitAdd( "Particle Lance")
-end
-special_ships["Za'lek Bomber Drone"] = function( p )
-   p:outfitAdd( "Electron Burst Cannon" )
-   p:outfitAdd( "Electron Burst Cannon" )
-end
-special_ships["Za'lek Heavy Drone"] = function( p )
-   p:outfitAdd( "Orion Lance" )
-   p:outfitAdd( "Orion Lance" )
-   p:outfitAdd( "Electron Burst Cannon" )
-end
 
 
 --[[
@@ -212,7 +204,7 @@ local function print_debug( p, st, ss, outfit_list, params, constraints, energyg
       end
    end
    print(_("Equipment:"))
-   for j,o in ipairs(p:outfits()) do
+   for j,o in ipairs(p:outfitsList()) do
       print( "   "..o:name() )
    end
    local stn = p:stats()
@@ -239,9 +231,17 @@ function optimize.optimize( p, cores, outfit_list, params )
    params = params or eparams.default()
    params.goodness = params.goodness or optimize.goodness_default
    local sparams = optimize.sparams
+   local pm = p:memory()
+   pm.equipopt_params = params
 
    -- Naked ship
    local ps = p:ship()
+   local pt = ps:tags()
+   if pt.noequip then -- Don't equip
+      -- Set up useful outfits
+      ai_setup.setup(p)
+      return
+   end
    p:outfitRm( "all" )
 
    -- Special ships used fixed outfits
@@ -255,11 +255,19 @@ function optimize.optimize( p, cores, outfit_list, params )
          end
          return false
       end
+      -- Set up useful outfits
+      ai_setup.setup(p)
       return true
    end
 
+   -- Special case bioships
+   if pt.bioship and not p:shipvarPeek("bioship_init") then
+      local stage = bioship.maxstage( p )
+      bioship.simulate( p, rnd.rnd(1,stage) )
+   end
+
    -- Handle cores
-   if cores then
+   if cores and not pt.nocores then
       -- Don't actually have to remove cores as it should overwrite default
       -- cores as necessary
       --p:outfitRm( "cores" )
@@ -287,19 +295,21 @@ function optimize.optimize( p, cores, outfit_list, params )
    local slots_base = ps:getSlots()
    for m,o in ipairs(outfit_list) do
       if not usable_outfits[o] then
-         for k,v in ipairs( slots_base ) do
-            local ok = true
-            -- Afterburners will be ignored if the ship is too heavy
-            if o:type() == "Afterburner" then
-               local spec = o:specificstats()
-               if spec.mass_limit < 0.8*ss.engine_limit then
-                  ok = false
-               end
+         local ok = true
+         -- Afterburners will be ignored if the ship is too heavy
+         if o:type() == "Afterburner" then
+            local spec = o:specificstats()
+            if spec.mass_limit < 0.8*ss.engine_limit then
+               ok = false
             end
-            -- Check to see if fits slot
-            if ok and ps:fitsSlot( k, o ) then
-               usable_outfits[o] = true
-               break
+         end
+         if ok then
+            for k,v in ipairs(slots_base) do
+               -- Check to see if fits slot
+               if ps:fitsSlot( k, o ) then
+                  usable_outfits[o] = true
+                  break
+               end
             end
          end
       end
@@ -358,6 +368,9 @@ function optimize.optimize( p, cores, outfit_list, params )
       oo.name     = out:nameRaw()
       oo.outfit   = out
       oo.slot, oo.size = out:slot()
+      oo.is_weap = (oo.slot=="Weapon")
+      oo.is_util = (oo.slot=="Utility")
+      oo.is_stru = (oo.slot=="Structure")
       local os = outfit_stats[oo.name]
       oo.stats    = os
       oo.dps, oo.disable, oo.eps, oo.range, oo.trackmin, oo.trackmax, oo.lockon, oo.iflockon, oo.seeker = out:weapstats( p )
@@ -429,7 +442,8 @@ function optimize.optimize( p, cores, outfit_list, params )
 
    -- Figure out slots
    local slots = {}
-   for k,v in ipairs( slots_base ) do
+   local slots_w, slots_u, slots_s = {}, {}, {}
+   for k,v in ipairs(slots_base) do
       local has_outfits = {}
       local outfitpos = {}
       for m,o in ipairs(outfit_list) do
@@ -455,6 +469,15 @@ function optimize.optimize( p, cores, outfit_list, params )
          -- potential outfits, but only one constraint
          ncols = ncols + #v.outfits
          nrows = nrows + 1
+
+         -- Sort by type to apply limits
+         if v.type=="Weapon" then
+            table.insert( slots_w, v )
+         elseif v.type=="Utility" then
+            table.insert( slots_u, v )
+         elseif v.type=="Structure" then
+            table.insert( slots_s, v )
+         end
       end
    end
 
@@ -474,6 +497,16 @@ function optimize.optimize( p, cores, outfit_list, params )
    if #same_list > 0 then
       nrows = nrows + #same_list
    end
+   -- Add max limits
+   if params.max_weap then
+      nrows = nrows+1
+   end
+   if params.max_util then
+      nrows = nrows+1
+   end
+   if params.max_stru then
+      nrows = nrows+1
+   end
    local ntype_range = 0
    for k,v in pairs(params.type_range) do ntype_range = ntype_range+1 end
    nrows = nrows + ntype_range
@@ -520,6 +553,23 @@ function optimize.optimize( p, cores, outfit_list, params )
       lp:set_row( v.id, name, v.min, v.max )
       r = r+1
    end
+   -- Add maximum amount of slots to use
+   local r_weap, r_util, r_stru
+   if params.max_weap then
+      r_weap = r
+      lp:set_row( r_weap, "max_weap", nil, params.max_weap )
+      r = r+1
+   end
+   if params.max_util then
+      r_util = r
+      lp:set_row( r_util, "max_util", nil, params.max_util )
+      r = r+1
+   end
+   if params.max_stru then
+      r_stru = r
+      lp:set_row( r_stru, "max_stru", nil, params.max_stru )
+      r = r+1
+   end
    -- Add outfit checks
    local c = 1
    for i,s in ipairs(slots) do
@@ -570,6 +620,22 @@ function optimize.optimize( p, cores, outfit_list, params )
             table.insert( ja, c )
             table.insert( ar, 1 )
          end
+         -- Maximum of slot type
+         if params.max_weap then
+            table.insert( ia, r_weap )
+            table.insert( ja, c )
+            table.insert( ar, 1 )
+         end
+         if params.max_util then
+            table.insert( ia, r_util )
+            table.insert( ja, c )
+            table.insert( ar, 1 )
+         end
+         if params.max_stru then
+            table.insert( ia, r_stru )
+            table.insert( ja, c )
+            table.insert( ar, 1 )
+         end
          -- Check type range
          if ntype_range > 0 then
             local rn = params.type_range[ stats.name ]
@@ -622,7 +688,7 @@ function optimize.optimize( p, cores, outfit_list, params )
          -- Mass constraint
          mmod = mmod * 2
          massgoal = mmod * params.max_mass * ss.engine_limit - st.mass
-         lp:set_row( 2, "mass", nil, massgoal )
+         lp:set_row( 3, "mass", nil, massgoal )
          -- Energy constraint
          energygoal = energygoal / 1.5
          lp:set_row( 2, "energy_regen", nil, st.energy_regen - emod*energygoal )
@@ -692,6 +758,9 @@ function optimize.optimize( p, cores, outfit_list, params )
    -- Fill ammo
    p:fillAmmo()
 
+   -- Set up useful outfits
+   ai_setup.setup(p)
+
    -- Check
    if __debugging then
       local b, s = p:spaceworthy()
