@@ -36,19 +36,21 @@ local function _H( x, y, r, sx, sy )
       -- Rendering to screen
       H = graphics._O
    end
-   H = H * graphics._T[1].T
-   if r == 0 then
-      H = H:translate(x,y)
-           :scale( sx, -sy )
-           :translate(0,-1)
-   else
-      local hw = sx/2
-      local hh = sy/2
-      H = H:translate(x+hw,y+hh)
-           :rotate2d(r)
-           :translate(-hw,-hh)
-           :scale( sx, -sy )
-           :translate(0,-1)
+   H = graphics._T[1].T * H
+   if x then
+      if r == 0 then
+         H = H:translate(x,y)
+            :scale( sx, -sy )
+            :translate(0,-1)
+      else
+         local hw = sx/2
+         local hh = sy/2
+         H = H:translate(x+hw,y+hh)
+            :rotate2d(r)
+            :translate(-hw,-hh)
+            :scale( sx, -sy )
+            :translate(0,-1)
+      end
    end
    return H
 end
@@ -202,6 +204,14 @@ function graphics.newQuad( x, y, width, height, sw, sh )
 end
 
 
+--[[
+-- Line stuff
+--]]
+function graphics.line( ... )
+   naev.gfx.renderLinesH( _H(), graphics._fgcol, ... )
+end
+
+
 --[[
 -- Transformation class
 --]]
@@ -307,9 +317,9 @@ function graphics.clear( ... )
       col = _scol( r, g, b, a )
    elseif type(arg[1])=="table" then
       local r = arg[1][1]
-      local g = arg[1][1]
-      local b = arg[1][1]
-      local a = arg[1][1] or 1
+      local g = arg[1][2]
+      local b = arg[1][3]
+      local a = arg[1][4] or 1
       col = _scol( r, g, b, a )
    end
    if graphics._canvas then
@@ -484,6 +494,9 @@ end
 function graphics.Font:setOutline( size )
    self.outline = size
 end
+function graphics.Font:getOutline()
+   return self.outline
+end
 function graphics.setFont( fnt ) graphics._font = fnt end
 function graphics.getFont() return graphics._font end
 function graphics.setNewFont( file, size, ...  )
@@ -496,11 +509,29 @@ end
 --[[
 -- Shader class
 --]]
+-- Set some sane defaults.
+local _pixelcode = [[
+vec4 effect( vec4 color, Image tex, vec2 texture_coords, vec2 screen_coords )
+{
+   vec4 texcolor = texture(tex, texture_coords );
+   return texcolor * color;
+}
+]]
+local _vertexcode = [[
+vec4 position( mat4 transform_projection, vec4 vertex_position )
+{
+   return transform_projection * vertex_position;
+}
+]]
 graphics.Shader = class.inheritsFrom( object.Object )
 graphics.Shader._type = "Shader"
 function graphics.newShader( pixelcode, vertexcode )
+   pixelcode = pixelcode or _pixelcode
+   vertexcode = vertexcode or _vertexcode
+
    local prepend = [[
 #version 140
+#define _LOVE
 // Syntax sugar
 #define Image           sampler2D
 #define ArrayImage      sampler2DArray
@@ -615,14 +646,18 @@ graphics.Canvas._type = "Canvas"
 function graphics.newCanvas( width, height, settings )
    settings = settings or {}
    local c = graphics.Canvas.new()
-   local nw, nh = naev.gfx.dim()
-   width  = width or nw
-   height = height or nh
-   local dpiscale = settings.dpiscale or graphics.getDPIScale()
-   c.canvas = naev.canvas.new( width*dpiscale, height*dpiscale )
-   c.w = width
-   c.h = height
-   c.s = 1/dpiscale
+   if type(width)=='userdata' then -- assume Naev canvas
+      c.canvas = width
+      c.w, c.h = width:dims()
+      c.s = 1
+   else
+      local nw, nh = naev.gfx.dim()
+      c.w = width or nw
+      c.h = height or nh
+      local dpiscale = settings.dpiscale or graphics.getDPIScale()
+      c.canvas = naev.canvas.new( c.w*dpiscale, c.h*dpiscale )
+      c.s = 1/dpiscale
+   end
    -- Set texture
    local t = graphics.Image.new()
    t.tex = c.canvas:getTex()
@@ -664,26 +699,17 @@ function graphics.getDPIScale()
    local _w, _h, scale = naev.gfx.dim()
    return 1/scale
 end
-
-
--- Set some sane defaults.
-local _pixelcode = [[
-vec4 effect( vec4 color, Image tex, vec2 texture_coords, vec2 screen_coords )
-{
-   vec4 texcolor = texture(tex, texture_coords );
-   return texcolor * color;
-}
-]]
-local _vertexcode = [[
-vec4 position( mat4 transform_projection, vec4 vertex_position )
-{
-   return transform_projection * vertex_position;
-}
-]]
+-- Have to initialize properly the dimensions here for when using the graphics
+-- API outside of the love framework
+local nw, nh = naev.gfx.dim()
+love.x = 0
+love.y = 0
+love.w = nw
+love.h = nh
 graphics.setDefaultFilter( "linear", "linear", 1 )
 graphics.setNewFont( 12 )
 graphics.origin()
-graphics._shader_default = graphics.newShader( _pixelcode, _vertexcode )
+graphics._shader_default = graphics.newShader()
 graphics.setShader( graphics._shader_default )
 graphics.setCanvas( nil )
 --graphics._mode = "alpha"
