@@ -16,10 +16,12 @@ local transitions = require 'vn.transitions'
 local log         = require "vn.log"
 local sdf         = require "vn.sdf"
 local opt         = require "vn.options"
+local luaspfx     = require "luaspfx"
+local luatk       = require "luatk"
 
 local vn = {
    speed = var.peek("vn_textspeed") or 0.025,
-   color = {1,1,1},
+   autoscroll = (var.peek("vn_autoscroll")==true),
 
    -- Internal usage
    _default = {
@@ -56,7 +58,6 @@ local function _setdefaults()
    vn._default.textbox_font = graphics.newFont(16)
    vn._default.textbox_font:setOutline( 0.5 )
    vn._default.textbox_w = 800
-   vn._default.textbox_tw = vn._default.textbox_w-60
    local fonth = vn._default.textbox_font:getLineHeight()
    vn._default.textbox_h = math.floor(200 / fonth) * fonth + 20*2
    vn._default.textbox_x = ox + (mw-vn._default.textbox_w)/2
@@ -376,6 +377,12 @@ Key press handler.
    @tparam string key Name of the key pressed.
 --]]
 function vn.keypressed( key )
+   local tkopen = luatk.isOpen()
+   if not tkopen and string.lower(naev.keyGet( "menu" )) == key then
+      naev.menuSmall()
+      return true
+   end
+
    if vn._show_options then
       opt.keypressed( key )
       return true
@@ -399,7 +406,7 @@ function vn.keypressed( key )
    end
 
    if not vn._show_log then
-      if key=="tab" or key=="escape" then
+      if not tkopen and (key=="tab" or key=="escape") then
          vn._show_log = not vn._show_log
          log.open( vn.textbox_font )
          return true
@@ -423,7 +430,7 @@ end
 --[[--
 Mouse move handler.
 --]]
-function vn.mousemoved( mx, my )
+function vn.mousemoved( mx, my, dx, dy )
    if vn._show_options then
       opt.mousemoved( mx, my )
       return true
@@ -431,10 +438,14 @@ function vn.mousemoved( mx, my )
 
    if vn.show_options and _inbox( mx, my, vn.options_x, vn.options_y, vn.options_w, vn.options_h ) then
       vn._options_over = true
+      return true
    else
       vn._options_over = false
    end
-   return true
+
+   if vn.isDone() then return false end
+   local s = vn._states[ vn._state ]
+   return s:mousemoved( mx, my, dx, dy )
 end
 
 --[[--
@@ -455,7 +466,7 @@ function vn.mousepressed( mx, my, button )
    end
 
    if vn.show_options and _inbox( mx, my, vn.options_x, vn.options_y, vn.options_w, vn.options_h ) then
-      opt.open()
+      opt.open( vn )
       vn._show_options = true
       return
    end
@@ -474,8 +485,21 @@ Mouse released handler.
 function vn.mousereleased( mx, my, button )
    if vn._show_options then
       opt.mousereleased( mx, my, button )
+      return true
    end
-   return true
+
+   if vn.isDone() then return false end
+   local s = vn._states[ vn._state ]
+   return s:mousereleased( mx, my, button )
+end
+
+--[[--
+Text input handler.
+--]]
+function vn.textinput( str )
+   if vn.isDone() then return false end
+   local s = vn._states[ vn._state ]
+   return s:textinput( str )
 end
 
 -- Helpers
@@ -483,16 +507,18 @@ end
 Makes the player say something.
 
    @tparam string what What is being said.
+   @tparam bool noclear Whether or not to clear the text buffer.
    @tparam bool nowait Whether or not to wait for player input when said.
 ]]
-function vn.me( what, nowait ) vn.say( "You", what, nowait ) end
+function vn.me( what, noclear, nowait ) vn.say( "You", what, noclear, nowait ) end
 --[[--
 Makes the narrator say something.
 
    @tparam string what What is being said.
+   @tparam bool noclear Whether or not to clear the text buffer.
    @tparam bool nowait Whether or not to wait for player input when said.
 ]]
-function vn.na( what, nowait ) vn.say( "Narrator", what, nowait ) end
+function vn.na( what, noclear, nowait ) vn.say( "Narrator", what, noclear, nowait ) end
 
 --[[
 -- State
@@ -509,7 +535,10 @@ function vn.State.new()
    s._draw = _dummy
    s._update = _dummy
    s._mousepressed = _dummy
+   s._mousereleased = _dummy
+   s._mousemoved = _dummy
    s._keypressed = _dummy
+   s._textinput = _dummy
    s.done = false
    return s
 end
@@ -531,11 +560,26 @@ function vn.State:mousepressed( mx, my, button )
    vn._checkDone()
    return ret
 end
+function vn.State:mousereleased( mx, my, button )
+   local ret = self:_mousereleased( mx, my, button )
+   vn._checkDone()
+   return ret
+end
+function vn.State:mousemoved( mx, my, dx, dy )
+   local ret = self:_mousemoved( mx, my, dx, dy )
+   vn._checkDone()
+   return ret
+end
 function vn.State:keypressed( key )
    local ret = self:_keypressed( key )
    vn._checkDone()
    return ret
 end
+function vn.State:textinput( key )
+   local ret = self:_textinput( key )
+   vn._checkDone()
+   return ret
+end
 function vn.State:isDone() return self.done end
 --[[
 -- Scene
@@ -562,6 +606,9 @@ function vn.StateScene:_init()
    -- Set alpha to max (since transitions will be used in general)
    vn._globalalpha = 1
 
+   -- Clear stuff
+   vn._buffer = ""
+
    _finish(self)
 end
 --[[
@@ -615,7 +662,7 @@ end
 -- Say
 --]]
 vn.StateSay = {}
-function vn.StateSay.new( who, what )
+function vn.StateSay.new( who, what, noclear )
    local s = vn.State.new()
    s._init = vn.StateSay._init
    s._update = vn.StateSay._update
@@ -624,6 +671,7 @@ function vn.StateSay.new( who, what )
    s._type = "Say"
    s.who = who
    s._what = what
+   s._noclear = noclear
    return s
 end
 function vn.StateSay:_init()
@@ -636,16 +684,24 @@ function vn.StateSay:_init()
    self._textbuf = self.what
    -- Parse for line breaks and insert newlines
    local font = vn.textbox_font
-   local _maxw, wrappedtext = font:getWrap( self._textbuf, vn.textbox_tw )
+   local _maxw, wrappedtext = font:getWrap( self._textbuf, vn.textbox_w-60 )
    self._textbuf = table.concat( wrappedtext, "\n" )
    -- Set up initial buffer
    self._timer = vn.speed
+   if self._noclear then
+      self._pos = utf8.len( vn._buffer )
+      self._textbuf = vn._buffer .. self._textbuf
+      self._text = vn._buffer
+      vn._buffer = self._text
+   else
+      self._pos = utf8.next( self._textbuf )
+      self._text = ""
+      -- Initialize scroll
+      vn._buffer_y = 0
+   end
    self._len = utf8.len( self._textbuf )
-   self._pos = utf8.next( self._textbuf )
-   self._text = ""
    local c = vn._getCharacter( self.who )
    vn._bufcol = c.color or vn._default._bufcol
-   vn._buffer = self._text
    if c.hidetitle then
       vn._title = nil
    else
@@ -656,9 +712,6 @@ function vn.StateSay:_init()
       v.talking = false
    end
    c.talking = true
-
-   -- Initialize scroll
-   vn._buffer_y = 0
 end
 function vn.StateSay:_update( dt )
    self._timer = self._timer - dt
@@ -669,7 +722,7 @@ function vn.StateSay:_update( dt )
          return
       end
       self._pos = utf8.next( self._textbuf, self._pos )
-      self._text = string.sub( self._textbuf, 1, self._pos )
+      self._text = utf8.sub( self._textbuf, 1, self._pos )
       self._timer = self._timer + vn.speed
       vn._buffer = self._text
 
@@ -683,10 +736,14 @@ function vn.StateSay:_update( dt )
       -- Checks to see if we should scroll down
       local bh = 20
       local font = vn.textbox_font
-      local _maxw, wrappedtext = font:getWrap( self._text, vn.textbox_tw )
+      local _maxw, wrappedtext = font:getWrap( self._text, vn.textbox_w-60 )
       local lh = font:getLineHeight()
       if (lh * #wrappedtext + bh + vn._buffer_y > vn.textbox_h) then
-         vn._buffer_y = vn._buffer_y - lh
+         if vn.autoscroll then
+            vn._buffer_y = vn._buffer_y - lh
+         else
+            vn.StateSay._finish( self )
+         end
       end
    end
 end
@@ -1090,16 +1147,15 @@ end
 
 --[[--
 A visual novel character.
-
-@type Character
 --]]
 vn.Character = {}
 --[[--
 Makes a character say something.
    @tparam string what What is being said.
+   @tparam bool noclear Whether or not to clear the text buffer.
    @tparam bool nowait Whether or not to wait for player input when said.
 --]]
-function vn.Character:say( what, nowait ) return vn.say( self.who, what, nowait ) end
+function vn.Character:say( what, noclear, nowait ) return vn.say( self.who, what, noclear, nowait ) end
 vn.Character_mt = { __index = vn.Character, __call = vn.Character.say }
 --[[--
 Creates a new character without adding it to the VN.
@@ -1118,8 +1174,10 @@ function vn.Character.new( who, params )
    if pimage ~= nil then
       local img
       if type(pimage)=='string' then
-         local searchpath = { "",
-               "gfx/vn/characters/" }
+         local searchpath = {
+            "",
+            "gfx/vn/characters/",
+         }
          for k,s in ipairs(searchpath) do
             local info = filesystem.getInfo( s..pimage )
             if info ~= nil then
@@ -1132,6 +1190,10 @@ function vn.Character.new( who, params )
          if img == nil then
             error(string.format(_("vn: character image '%s' not found!"),pimage))
          end
+         local iw, ih = img:getDimensions()
+         if iw <= 256 or ih <= 256 then
+            img:setFilter("nearest")
+         end
       elseif pimage._type=="ImageData" then
          img = graphics.newImage( pimage )
       else
@@ -1291,11 +1353,12 @@ Has a character say something.
 
    @tparam string who The name of the character that is saying something.
    @tparam string what What the character is saying.
+   @tparam[opt=false] bool noclear Whether or not to clear the text buffer.
    @tparam[opt=false] bool nowait Whether or not to introduce a wait or just skip to the next text right away (defaults to false).
 ]]
-function vn.say( who, what, nowait )
+function vn.say( who, what, noclear, nowait )
    vn._checkstarted()
-   table.insert( vn._states, vn.StateSay.new( who, what ) )
+   table.insert( vn._states, vn.StateSay.new( who, what, noclear ) )
    if not nowait then
       table.insert( vn._states, vn.StateWait.new() )
    end
@@ -1355,7 +1418,7 @@ function vn.music( filename, params, dontstop )
    else
       vn.func( function ()
          if not dontstop then
-            music.stop(true)
+            music.stop()
             lmusic.stop()
          end
          vn._handle_music = true
@@ -1487,18 +1550,15 @@ Plays a sound.
 --]]
 function vn.sfx( sfx, params )
    params = params or {}
-   vn._checkstarted()
+   if vn._started then
+      luaspfx.sfx( false, nil, sfx, params )
+      return
+   end
    local s = vn.State.new()
    s._init = function (state)
       local _sfx = sfx:clone()
       s._sfx = _sfx
-      _sfx:play()
-      if params.pitch then
-         _sfx:setPitch( params.pitch )
-      end
-      if params.effect then
-         _sfx:setEffect( params.effect )
-      end
+      luaspfx.sfx( false, nil, _sfx, params )
       _finish(state)
    end
    table.insert( vn._states, s )
